@@ -75,6 +75,6 @@ isalnum (int c)
 #if _PICOLIBC_CTYPE_SMALL
     return isalpha(c) || isdigit(c);
 #else
-    return __CTYPE_PTR[c+1] & (_U|_L|_N);
+    return __CTYPE_PTR[c+1] & (__CTYPE_UPPER|__CTYPE_LOWER|__CTYPE_DIGIT);
 #endif
 }
