@@ -14,6 +14,6 @@ isprint_l (int c, locale_t locale)
     (void) locale;
     return isprint(c);
 #else
-    return __CTYPE_PTR_L (locale)[c+1] & (_P|_U|_L|_N|_B);
+    return __CTYPE_PTR_L (locale)[c+1] & (__CTYPE_PUNCT|__CTYPE_UPPER|__CTYPE_LOWER|__CTYPE_DIGIT|__CTYPE_BLANK);
 #endif
 }
