@@ -13,7 +13,7 @@ isupper_l (int c, locale_t locale)
     (void) locale;
     return isupper(c);
 #else
-    return (__CTYPE_PTR_L (locale)[c+1] & (_U|_L)) == _U;
+    return (__CTYPE_PTR_L (locale)[c+1] & (__CTYPE_UPPER|__CTYPE_LOWER)) == __CTYPE_UPPER;
 #endif
 }
 
