@@ -70,7 +70,7 @@ No supporting OS subroutines are required.
 int
 iswalnum (wint_t c)
 {
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
     return iswalnum_l (c, 0);
 #else
     return c < (wint_t)0x100 ? isalnum (c) : 0;
