@@ -69,7 +69,7 @@ No supporting OS subroutines are required.
 int
 iswlower (wint_t c)
 {
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
   return iswlower_l (c, 0);
 #else
   return c < (wint_t)0x100 ? islower (c) : 0;
