@@ -12,10 +12,10 @@ int
 iswupper_l (wint_t c, locale_t locale)
 {
   (void) locale;
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
   uint16_t cat = __ctype_table_lookup (c, locale);
   return (cat & CLASS_upper) || ((cat & CLASS_case) && towlower_l(c, locale) != c);
 #else
   return c < 0x100 ? isupper (c) : 0;
-#endif /* _MB_CAPABLE */
+#endif /* __MB_CAPABLE */
 }
