@@ -31,7 +31,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /* based on eucjp-208A.txt */
 
 /* a1 is contiguous from a1a1 to a1fe */
-static unsigned short a1[] = {
+static const unsigned short a1[] = {
   0x3000,
   0x3001,
   0x3002,
@@ -129,7 +129,7 @@ static unsigned short a1[] = {
 };
 
 /* a2 has a number of holes between a2a1 and a2fe which we fill with 0x0000 */
-static unsigned short a2[] = {
+static const unsigned short a2[] = {
   0x25C6,
   0x25A1,
   0x25A0,
@@ -229,7 +229,7 @@ static unsigned short a2[] = {
 
 /* a3a1 to a3fe is mostly contiguous.  Conversion output values are
    of the form 0xFFxx where xx is (yy - 0xA0) where the input is 0xA3yy */
-static unsigned char a3[] = {
+static const unsigned char a3[] = {
   0,
   0,
   0,
@@ -329,7 +329,7 @@ static unsigned char a3[] = {
 /* transform = 0x30xx where xx = last byte */
 
 /* a6 is mostly contiguous from a6a1 to a6d8 */
-static unsigned short a6[] = {
+static const unsigned short a6[] = {
   0x0391,
   0x0392,
   0x0393,
@@ -389,7 +389,7 @@ static unsigned short a6[] = {
 };
 
 /* a7 is mostly contiguous from a7a1 to a7f1 */
-static unsigned short a7[] = {
+static const unsigned short a7[] = {
   0x0410,
   0x0411,
   0x0412,
@@ -474,7 +474,7 @@ static unsigned short a7[] = {
 };
 
 /* a8 is contiguous from a8a1 to a8c0 */
-static unsigned short a8[] = {
+static const unsigned short a8[] = {
   0x2500,
   0x2502,
   0x250C,
@@ -512,7 +512,7 @@ static unsigned short a8[] = {
 /* no conversion a9 to af */
 
 /* b0a1 to cfd3 is contiguous except for illegal sequences with 0xfe */
-static unsigned short b02cf[] = {
+static const unsigned short b02cf[] = {
   0x4E9C,
   0x5516,
   0x5A03,
@@ -3482,7 +3482,7 @@ static unsigned short b02cf[] = {
 
 /* d0a1 to f4a6 is contiguous */
 
-static unsigned short d02f4[] = {
+static const unsigned short d02f4[] = {
   0x5F0C,
   0x4E10,
   0x4E15,
