@@ -8,7 +8,7 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
 #undef toascii_l
 
 int
-toascii_l (int c, struct __locale_t *locale)
+toascii_l (int c, locale_t locale)
 {
   (void) locale;
   return c & 0177;
