@@ -4,8 +4,8 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
  */
 #define _DEFAULT_SOURCE
 #include <ctype.h>
-#if defined (_MB_EXTENDED_CHARSETS_ISO) \
-    || defined (_MB_EXTENDED_CHARSETS_WINDOWS)
+#if defined (__MB_EXTENDED_CHARSETS_ISO) \
+    || defined (__MB_EXTENDED_CHARSETS_WINDOWS)
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -17,8 +17,8 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
 int
 toupper_l (int c, locale_t locale)
 {
-#if defined (_MB_EXTENDED_CHARSETS_ISO) \
-    || defined (_MB_EXTENDED_CHARSETS_WINDOWS)
+#if defined (__MB_EXTENDED_CHARSETS_ISO) \
+    || defined (__MB_EXTENDED_CHARSETS_WINDOWS)
   if ((unsigned char) c <= 0x7f)
     return islower_l (c, locale) ? c - 'a' + 'A' : c;
   else if (c != EOF && __locale_mb_cur_max_l (locale) == 1
