@@ -73,9 +73,9 @@ No supporting OS subroutines are required.
 wint_t
 towlower (wint_t c)
 {
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
   return towlower_l(c, 0);
 #else
   return c < 0x00ff ? (wint_t)(tolower ((int)c)) : c;
-#endif /* _MB_CAPABLE */
+#endif /* __MB_CAPABLE */
 }
