@@ -6,7 +6,7 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
 #include <wctype.h>
 
 wctype_t
-wctype_l (const char *c, struct __locale_t *locale)
+wctype_l (const char *c, locale_t locale)
 {
   (void) locale;
   return wctype (c);
