@@ -1,31 +1,31 @@
 /*
-Copyright (c) 1982, 1986, 1993
-The Regents of the University of California.  All rights reserved.
+  Copyright (c) 1982, 1986, 1993
+  The Regents of the University of California.  All rights reserved.
 
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-1. Redistributions of source code must retain the above copyright
-notice, this list of conditions and the following disclaimer.
-2. Redistributions in binary form must reproduce the above copyright
-notice, this list of conditions and the following disclaimer in the
-documentation and/or other materials provided with the distribution.
-3. Neither the name of the University nor the names of its contributors
-may be used to endorse or promote products derived from this software
-without specific prior written permission.
+  Redistribution and use in source and binary forms, with or without
+  modification, are permitted provided that the following conditions
+  are met:
+  1. Redistributions of source code must retain the above copyright
+  notice, this list of conditions and the following disclaimer.
+  2. Redistributions in binary form must reproduce the above copyright
+  notice, this list of conditions and the following disclaimer in the
+  documentation and/or other materials provided with the distribution.
+  3. Neither the name of the University nor the names of its contributors
+  may be used to endorse or promote products derived from this software
+  without specific prior written permission.
 
-THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
-ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
-FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGE.
- */
+  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+  SUCH DAMAGE.
+*/
 #ifndef __SYS_CONFIG_H__
 #define __SYS_CONFIG_H__
 
@@ -37,10 +37,6 @@ SUCH DAMAGE.
 #define MALLOC_ALIGNMENT 16
 #endif
 
-#ifdef __AMDGCN__
-#define __DYNAMIC_REENT__
-#endif
-
 /* exceptions first */
 #if defined(__H8500__) || defined(__W65__)
 #define __SMALL_BITFIELDS
@@ -108,18 +104,9 @@ SUCH DAMAGE.
 #define _POINTER_INT short
 #endif
 
-#ifdef ___AM29K__
-#define _FLOAT_RET double
-#endif
-
 #ifdef __i386__
-#ifndef __unix__
-/* in other words, go32 */
-#define _FLOAT_RET double
-#endif
 #if defined(__linux__) || defined(__RDOS__)
 /* we want the reentrancy structure to be returned by a function */
-#define __DYNAMIC_REENT__
 #define HAVE_GETDATE
 #ifndef __LARGE64_FILES
 #define __LARGE64_FILES 1
@@ -138,35 +125,13 @@ SUCH DAMAGE.
 #define _POINTER_INT short
 #endif
 
-#if defined(__v850) && !defined(__rtems__)
-#define __ATTRIBUTE_IMPURE_PTR__ __attribute__((__sda__))
-#endif
-
-/* For the PowerPC eabi, force the _impure_ptr to be in .sdata */
-#if defined(__PPC__)
-#if defined(_CALL_SYSV)
-#define __ATTRIBUTE_IMPURE_PTR__ __attribute__((__section__(".sdata")))
-#endif
-#ifdef __SPE__
-#define _LONG_DOUBLE double
-#endif
-#endif
-
-/* Configure small REENT structure for Xilinx MicroBlaze platforms */
 #if defined (__MICROBLAZE__) && !defined(__rtems__)
-#ifndef _REENT_SMALL
-#define _REENT_SMALL
-#endif
 /* Xilinx XMK uses Unix98 mutex */
 #ifdef __XMK__
 #define _UNIX98_THREAD_MUTEX_ATTRIBUTES
 #endif
 #endif
 
-#if defined(__mips__) && !defined(__rtems__)
-#define __ATTRIBUTE_IMPURE_PTR__ __attribute__((__section__(".sdata")))
-#endif
-
 #ifdef __xstormy16__
 #define __SMALL_BITFIELDS
 #undef INT_MAX
@@ -176,13 +141,9 @@ SUCH DAMAGE.
 #define MALLOC_ALIGNMENT 8
 #define _POINTER_INT short
 #define __BUFSIZ__ 16
-#define _REENT_SMALL
 #endif
 
 #if defined __MSP430__
-#ifndef _REENT_SMALL
-#define _REENT_SMALL
-#endif
 
 #define __BUFSIZ__ 256
 #define __SMALL_BITFIELDS
@@ -207,7 +168,6 @@ SUCH DAMAGE.
 #define _POINTER_INT long
 #endif
 #define __BUFSIZ__ 16
-#define _REENT_SMALL
 #endif /* __m32c__ */
 
 #ifdef __SPU__
@@ -215,10 +175,6 @@ SUCH DAMAGE.
 #define __CUSTOM_FILE_IO__
 #endif
 
-#if defined(__or1k__) || defined(__or1knd__)
-#define __DYNAMIC_REENT__
-#endif
-
 /* This block should be kept in sync with GCC's limits.h.  The point
    of having these definitions here is to not include limits.h, which
    would pollute the user namespace, while still using types of the
@@ -237,7 +193,7 @@ SUCH DAMAGE.
 #  define __LONG_MAX__ LONG_MAX
 # else
 #  if defined (__alpha__) || (defined (__sparc__) && defined(__arch64__)) \
-      || defined (__sparcv9)
+    || defined (__sparcv9)
 #   define __LONG_MAX__ 9223372036854775807L
 #  else
 #   define __LONG_MAX__ 2147483647L
@@ -250,9 +206,6 @@ SUCH DAMAGE.
 #define _POINTER_INT long
 #endif
 
-#ifdef __frv__
-#define __ATTRIBUTE_IMPURE_PTR__ __attribute__((__section__(".sdata")))
-#endif
 #undef __RAND_MAX
 #if __INT_MAX__ == 32767
 #define __RAND_MAX 32767
@@ -263,7 +216,6 @@ SUCH DAMAGE.
 
 #if defined(__rtems__)
 #define __FILENAME_MAX__ 255
-#define __DYNAMIC_REENT__
 #endif
 
 #ifndef __WCHAR_MAX__
@@ -272,83 +224,61 @@ SUCH DAMAGE.
 #endif
 #endif
 
-#ifdef PICOLIBC_TLS
-#if (defined(__cplusplus) && (__cplusplus) >= 201103L) ||       \
+#ifdef __THREAD_LOCAL_STORAGE
+#if (defined(__cplusplus) && (__cplusplus) >= 201103L) ||               \
     (defined(__STDC_VERSION__) && (__STDC_VERSION__) >= 202311L)
-#define NEWLIB_THREAD_LOCAL thread_local
+#define __THREAD_LOCAL thread_local
 #elif defined(__STDC_VERSION__) && (__STDC_VERSION__) >= 201112L
-#define NEWLIB_THREAD_LOCAL _Thread_local
+#define __THREAD_LOCAL _Thread_local
 #else
-#define NEWLIB_THREAD_LOCAL __thread
+#define __THREAD_LOCAL __thread
 #endif
 #else
-#define NEWLIB_THREAD_LOCAL
+#define __THREAD_LOCAL
 #endif
 
-/* See if small reent asked for at configuration time and
-   is not chosen by the platform by default.  */
-#ifdef _WANT_REENT_SMALL
-#ifndef _REENT_SMALL
-#define _REENT_SMALL
-#endif
-#endif
-
-#ifdef _WANT_USE_LONG_TIME_T
-#ifndef _USE_LONG_TIME_T
-#define _USE_LONG_TIME_T
-#endif
-#endif
-
-#ifdef _WANT_USE_GDTOA
-#ifndef _USE_GDTOA
-#define _USE_GDTOA
-#endif
-#endif
-
-#ifdef _WANT_REENT_BACKWARD_BINARY_COMPAT
-#ifndef _REENT_BACKWARD_BINARY_COMPAT
-#define _REENT_BACKWARD_BINARY_COMPAT
-#endif
-#endif
-
-#define _REENT_THREAD_LOCAL
-
-#ifndef _MB_CAPABLE
+#ifndef __MB_CAPABLE
 /* Make sure all of these are disabled if multi-byte is disabled*/
-#undef _MB_EXTENDED_CHARSETS_ALL
-#undef _MB_EXTENDED_CHARSETS_ANY
-#undef _MB_EXTENDED_CHARSETS_UCS
-#undef _MB_EXTENDED_CHARSETS_ISO
-#undef _MB_EXTENDED_CHARSETS_WINDOWS
-#undef _MB_EXTENDED_CHARSETS_JIS
+#undef __MB_EXTENDED_CHARSETS_ALL
+#undef __MB_EXTENDED_CHARSETS_ANY
+#undef __MB_EXTENDED_CHARSETS_UCS
+#undef __MB_EXTENDED_CHARSETS_ISO
+#undef __MB_EXTENDED_CHARSETS_WINDOWS
+#undef __MB_EXTENDED_CHARSETS_JIS
 #endif
 
-/* If _MB_EXTENDED_CHARSETS_ALL is set, we want all of the extended
+/* If __MB_EXTENDED_CHARSETS_ALL is set, we want all of the extended
    charsets.  The extended charsets add a few functions and a couple
    of tables of a few K each. */
-#ifdef _MB_EXTENDED_CHARSETS_ALL
-#define _MB_EXTENDED_CHARSETS_UCS 1
-#define _MB_EXTENDED_CHARSETS_ISO 1
-#define _MB_EXTENDED_CHARSETS_WINDOWS 1
-#define _MB_EXTENDED_CHARSETS_JIS 1
+#ifdef __MB_EXTENDED_CHARSETS_ALL
+#define __MB_EXTENDED_CHARSETS_UCS 1
+#define __MB_EXTENDED_CHARSETS_ISO 1
+#define __MB_EXTENDED_CHARSETS_WINDOWS 1
+#define __MB_EXTENDED_CHARSETS_JIS 1
 #endif
 
-#if defined(_MB_EXTENDED_CHARSETS_ISO) ||     \
-    defined(_MB_EXTENDED_CHARSETS_WINDOWS) || \
-    defined(_MB_EXTENDED_CHARSETS_JIS)
-#define _MB_EXTENDED_CHARSETS_NON_UNICODE
+#if defined(__MB_EXTENDED_CHARSETS_ISO) ||       \
+    defined(__MB_EXTENDED_CHARSETS_WINDOWS) ||   \
+    defined(__MB_EXTENDED_CHARSETS_JIS)
+#define __MB_EXTENDED_CHARSETS_NON_UNICODE
 #endif
 
-#if defined(_MB_EXTENDED_CHARSETS_UCS) ||       \
-    defined(_MB_EXTENDED_CHARSETS_NON_UNICODE)
-#define _MB_EXTENDED_CHARSETS_ANY
+#if defined(__MB_EXTENDED_CHARSETS_UCS) ||       \
+    defined(__MB_EXTENDED_CHARSETS_NON_UNICODE)
+#define __MB_EXTENDED_CHARSETS_ANY
+#endif
+
+/* Figure out if the compiler supports the long double type. */
+#ifdef __SIZEOF_LONG_DOUBLE__
+#define __HAVE_LONG_DOUBLE
 #endif
 
 /* Figure out if long double is the same size as double. If the system
  * doesn't provide long double, then those values will be undefined
  * and cpp will substitute 0 for them in the test
  */
-#if LDBL_MANT_DIG == DBL_MANT_DIG && LDBL_MIN_EXP == DBL_MIN_EXP && \
+
+#if LDBL_MANT_DIG == DBL_MANT_DIG && LDBL_MIN_EXP == DBL_MIN_EXP &&     \
     LDBL_MAX_EXP == DBL_MAX_EXP
 #define _LDBL_EQ_DBL
 #endif
@@ -358,21 +288,8 @@ SUCH DAMAGE.
    simply call the double functions.  On Cygwin the long double functions
    are implemented independently from newlib to be able to use optimized
    assembler functions despite using the Microsoft x86_64 ABI. */
-#if defined (_LDBL_EQ_DBL) || defined (__CYGWIN__) || (defined(__SIZEOF_LONG_DOUBLE__) && __SIZEOF_LONG_DOUBLE__ <= 8) || (LDBL_MANT_DIG == 64 || LDBL_MANT_DIG == 113)
-#define _HAVE_LONG_DOUBLE_MATH
-#endif
-
-/*
- * When the address sanitizer is enabled, we must prevent the library
- * from even reading beyond the end of input data. This happens in
- * many optimized string functions.
- */
-#ifdef __has_feature
-#if __has_feature(address_sanitizer)
-#define PICOLIBC_NO_OUT_OF_BOUNDS_READS
-#endif
-#elif defined(__SANITIZE_ADDRESS__)
-#define PICOLIBC_NO_OUT_OF_BOUNDS_READS
+#if defined (_LDBL_EQ_DBL) || defined (__CYGWIN__) || (defined(__HAVE_LONG_DOUBLE) && __SIZEOF_LONG_DOUBLE__ <= 8) || (LDBL_MANT_DIG == 64 || LDBL_MANT_DIG == 113)
+#define __HAVE_LONG_DOUBLE_MATH
 #endif
 
 #endif /* __SYS_CONFIG_H__ */
