@@ -36,7 +36,7 @@
 #define _DEFAULT_SOURCE
 #include "locale_private.h"
 
-#ifdef _HAVE_POSIX_LOCALE_API
+#ifdef __HAVE_POSIX_LOCALE_API
 
 void
 freelocale (locale_t locale)
