@@ -26,7 +26,7 @@
 
 #include <picolibc.h>
 
-#if (defined (__OPTIMIZE_SIZE__) || defined (PREFER_SIZE_OVER_SPEED)) || !defined(__LP64__) || !defined(__ARM_NEON)
+#if (defined (__OPTIMIZE_SIZE__) || defined (__PREFER_SIZE_OVER_SPEED)) || !defined(__LP64__) || !defined(__ARM_NEON)
 # include "../../string/strchrnul.c"
 #else
 /* See strchrnul.S  */
