@@ -19,7 +19,7 @@
 #include <signal.h>
 #include "exit-value.h"
 
-void __attribute__((noreturn))
+void __noreturn
 abort (void)
 {
   write (2, "GCN Kernel Aborted\n", 19);
