@@ -31,7 +31,7 @@
 
 #include <picolibc.h>
 
-#if defined (__OPTIMIZE_SIZE__) || defined (PREFER_SIZE_OVER_SPEED)	\
+#if defined (__OPTIMIZE_SIZE__) || defined (__PREFER_SIZE_OVER_SPEED)	\
   || defined (__ARC_RF16__)
 # include "../../string/strcmp.c"
 #else
