@@ -1,6 +1,6 @@
 /* Copyright (c) 2013 Corinna Vinschen <corinna@vinschen.de> */
-#ifndef _MB_ENDIAN_H
-#define _MB_ENDIAN_H
+#ifndef __MB_ENDIAN_H
+#define __MB_ENDIAN_H
 
 /* Convenience macros for loading and store 4 bytes in a byte invariant way with
  * a singe instruction. Endianess affects this and we rely on MicroBlaze
