@@ -19,7 +19,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#ifndef _HAVE_ASSERT_FUNC
+#ifndef __HAVE_ASSERT_FUNC
 /* func can be NULL, in which case no function information is given.  */
 void
 __assert_func (const char *file,
@@ -30,7 +30,7 @@ __assert_func (const char *file,
   abort();
   /* NOTREACHED */
 }
-#endif /* _HAVE_ASSERT_FUNC */
+#endif /* __HAVE_ASSERT_FUNC */
 
 void
 __assert (const char *file,
