@@ -17,7 +17,7 @@
 
 #include <stdlib.h>
 
-void *_realloc_r (struct _reent *r, void *p, size_t n) _NOTHROW
+void *_realloc_r (struct _reent *r, void *p, size_t n) __nothrow
 {
   return realloc (p, n);
 }
