@@ -44,7 +44,7 @@
 #define __RISCV_HARD_FLOAT 32
 #endif
 
-#ifdef _WANT_MATH_ERRNO
+#ifdef __MATH_ERRNO
 #include <errno.h>
 #endif
 
@@ -68,7 +68,7 @@
 #if __RISCV_HARD_FLOAT >= 64
 
 /* anything with a 64-bit FPU has FMA */
-#define _HAVE_FAST_FMA 1
+#define __HAVE_FAST_FMA 1
 
 #define _fclass_d(_x) (__extension__(                                   \
                                {                                        \
@@ -84,7 +84,7 @@
 #if __RISCV_HARD_FLOAT >= 32
 
 /* anything with a 32-bit FPU has FMAF */
-#define _HAVE_FAST_FMAF 1
+#define __HAVE_FAST_FMAF 1
 
 #define _fclass_f(_x) (__extension__(                                   \
                                {                                        \
@@ -154,6 +154,20 @@ finite(double x)
         return __finite(x);
 }
 
+__declare_extern_inline(int)
+__isinfd(double x)
+{
+	long fclass = _fclass_d (x);
+	return (fclass & FCLASS_INF) != 0;
+}
+
+__declare_extern_inline(int)
+__isnand(double x)
+{
+	long fclass = _fclass_d (x);
+	return (fclass & FCLASS_NAN) != 0;
+}
+
 __declare_extern_inline(int)
 __fpclassifyd (double x)
 {
@@ -175,7 +189,7 @@ __declare_extern_inline(double)
 sqrt (double x)
 {
 	double result;
-#ifdef _WANT_MATH_ERRNO
+#ifdef __MATH_ERRNO
         if (isless(x, 0.0))
             errno = EDOM;
 #endif
@@ -247,6 +261,20 @@ finitef(float x)
         return __finitef(x);
 }
 
+__declare_extern_inline(int)
+__isinff(float x)
+{
+	long fclass = _fclass_f (x);
+	return (fclass & FCLASS_INF) != 0;
+}
+
+__declare_extern_inline(int)
+__isnanf(float x)
+{
+	long fclass = _fclass_f (x);
+	return (fclass & FCLASS_NAN) != 0;
+}
+
 __declare_extern_inline(int)
 __fpclassifyf (float x)
 {
@@ -268,7 +296,7 @@ __declare_extern_inline(float)
 sqrtf (float x)
 {
 	float result;
-#ifdef _WANT_MATH_ERRNO
+#ifdef __MATH_ERRNO
         if (isless(x, 0.0f))
             errno = EDOM;
 #endif
