@@ -11,6 +11,6 @@
 
 #include <picolibc.h>
 
-#if !defined(PREFER_SIZE_OVER_SPEED) && !defined(__OPTIMIZE_SIZE__)
+#if !defined(__PREFER_SIZE_OVER_SPEED) && !defined(__OPTIMIZE_SIZE__)
 #include "../../string/memmove.c"
 #endif
