@@ -49,7 +49,6 @@ typedef struct
   va_list ap;
 } c99_vsprintf_t;
 
-#ifndef _REENT_ONLY
 
 int
 vsprintf (char *__restrict str,
@@ -67,4 +66,3 @@ vsprintf (char *__restrict str,
   return __send_to_ppe(SPE_C99_SIGNALCODE, SPE_C99_VSPRINTF, &args);
 }
 
-#endif /* ! _REENT_ONLY */
