@@ -14,26 +14,37 @@
 #include <sys/types.h>
 #include <sys/_initfini.h>
 
-#ifdef _HAVE_INITFINI_ARRAY
+#ifdef __INIT_FINI_ARRAY
 
 /* Iterate over all the init routines.  */
 void
 __libc_init_array (void)
 {
-  size_t count;
-  size_t i;
+    void (**fn)(void);
+    void (**fn_end)(void);
 
-  count = __preinit_array_end - __preinit_array_start;
-  for (i = 0; i < count; i++)
-    __preinit_array_start[i] ();
+#ifdef __INIT_FINI_FUNCS
+    fn = __preinit_array_start;
+    fn_end = __preinit_array_end;
+    while (fn != fn_end)
+        (*fn++) ();
 
-#ifdef _HAVE_INIT_FINI
-  if (_init)
-    _init ();
+    if (_init)
+        _init ();
+
+    fn = __init_array_start;
+    fn_end = __preinit_array_end;
+    while (fn != fn_end)
+        (*fn++) ();
+#else
+    /*
+     * The init array immediately follows the preinit array,
+     * so we can just run both in one loop
+     */
+    fn = __bothinit_array_start;
+    fn_end = __bothinit_array_end;
+    while (fn != fn_end)
+        (*fn++)();
 #endif
-
-  count = __init_array_end - __init_array_start;
-  for (i = 0; i < count; i++)
-    __init_array_start[i] ();
 }
 #endif
