@@ -51,7 +51,7 @@ extern char __tdata_end[];      /* End of static tdata area */
 extern char __tbss_start[];     /* Start of static zero-initialized TLS data */
 extern char __tbss_end[];       /* End of static zero-initialized TLS data */
 
-#ifdef __PICOLIBC_CRT_RUNTIME_SIZE
+#ifdef __PICOCRT_RUNTIME_SIZE
 #define __tdata_size (__tdata_end - __tdata_start)
 #define __tbss_size (__tbss_end - __tbss_start)
 #define __tbss_offset (__tbss_start - __tdata_start)
