@@ -2,6 +2,7 @@
  * SPDX-License-Identifier: BSD-3-Clause
  *
  * Copyright © 2019 Keith Packard
+ * Copyright © 2024 Stephen Street
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -42,26 +43,5 @@
  * refer to it in an asm statement
  */
 #ifndef ARM_TLS_CP15
-void *__tls;
+void *__tls[ARM_TLS_COUNT];
 #endif
-
-/* The size of the thread control block.
- * TLS relocations are generated relative to
- * a location this far *before* the first thread
- * variable (!)
- * NB: The actual size before tp also includes padding
- * to align up to the alignment of .tdata/.tbss.
- */
-#define TCB_SIZE	8
-extern char __arm32_tls_tcb_offset;
-#define TP_OFFSET ((size_t)&__arm32_tls_tcb_offset)
-
-void
-_set_tls(void *tls)
-{
-#ifdef ARM_TLS_CP15
-	__asm__("mcr p15, 0, %0, cr13, cr0, 3" : : "r" (tls - TP_OFFSET));
-#else
-	__tls = (uint8_t *) tls - TP_OFFSET;
-#endif
-}
