@@ -32,9 +32,9 @@
 
 _BEGIN_STD_C
 /* Picolibc doesn't have any LC_COLLATE support, so this is never defined */
-#ifdef _HAVE_REAL_STRCOLL
+#ifdef __HAVE_REAL_STRCOLL
 int	__collate_range_cmp(int, int);
 #endif
-__END_DECLS
+_END_STD_C
 
 #endif /* !_COLLATE_H_ */
