@@ -82,9 +82,6 @@ struct match {
 };
 
 /* ========= begin header generated by ./mkh ========= */
-#ifdef __cplusplus
-extern "C" {
-#endif
 
 /* === engine.c === */
 static int matcher(struct re_guts *g, char *string, size_t nmatch, regmatch_t pmatch[], int eflags);
@@ -112,9 +109,6 @@ static void at(struct match *m, char *title, char *start, char *stop, sopno star
 static char *pchar(int ch);
 #endif
 
-#ifdef __cplusplus
-}
-#endif
 /* ========= end header generated by ./mkh ========= */
 
 #ifdef REDEBUG
