@@ -77,7 +77,7 @@ struct _bufhead {
 
 typedef BUFHEAD **SEGMENT;
 
-#ifdef __GNUC__
+#ifdef __GNUCLIKE_PRAGMA_DIAGNOSTIC
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wunknown-warning-option"
 /* 'bsize' is used directly with malloc/realloc which confuses -fanalyzer */
