@@ -40,7 +40,7 @@ asniprintf (char *buf,
      for _size.  */
   if (len > INT_MAX)
     {
-      _REENT_ERRNO(ptr) = EOVERFLOW;
+      errno = EOVERFLOW;
       return NULL;
     }
   f._bf._size = f._w = len;
