@@ -58,7 +58,7 @@ fdopen (
 {
   register FILE *fp;
   int flags, oflags;
-#ifdef _HAVE_FCNTL
+#ifdef __HAVE_FCNTL
   int fdflags, fdmode;
 #endif
 
@@ -66,13 +66,13 @@ fdopen (
     return 0;
 
   /* make sure the mode the user wants is a subset of the actual mode */
-#ifdef _HAVE_FCNTL
+#ifdef __HAVE_FCNTL
   if ((fdflags = fcntl (fd, F_GETFL, 0)) < 0)
     return 0;
   fdmode = fdflags & O_ACCMODE;
   if (fdmode != O_RDWR && (fdmode != (oflags & O_ACCMODE)))
     {
-      _REENT_ERRNO(ptr) = EBADF;
+      errno = EBADF;
       return 0;
     }
 #endif
@@ -87,7 +87,7 @@ fdopen (
      streams.  Someone may later clear O_APPEND on fileno(fp), but the
      stream must still remain in append mode.  Rely on __sflags
      setting __SAPP properly.  */
-#ifdef _HAVE_FCNTL
+#ifdef __HAVE_FCNTL
   if ((oflags & O_APPEND) && !(fdflags & O_APPEND))
     fcntl (fd, F_SETFL, fdflags | O_APPEND);
 #endif
