@@ -77,7 +77,7 @@ int
 ferror (FILE * fp)
 {
   int result;
-  CHECK_INIT(_REENT, fp);
+  CHECK_INIT();
   _newlib_flockfile_start (fp);
   result = __sferror (fp);
   _newlib_flockfile_end (fp);
