@@ -89,7 +89,7 @@ fgetc (
        FILE * fp)
 {
   int result;
-  CHECK_INIT(ptr, fp);
+  CHECK_INIT();
   _newlib_flockfile_start (fp);
   result = _sgetc ( fp);
   _newlib_flockfile_end (fp);
