@@ -108,7 +108,7 @@ fgets (
 
   s = buf;
 
-  CHECK_INIT(ptr, fp);
+  CHECK_INIT();
 
   _newlib_flockfile_start (fp);
 #ifdef __SCLE
