@@ -85,8 +85,7 @@ PORTABILITY
 <<fgetws_unlocked>> is a GNU extension.
 */
 
-#define _DEFAULT_SOURCE
-#include <_ansi.h>
+#define _GNU_SOURCE
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
