@@ -99,7 +99,7 @@ fputws (
 {
   size_t nbytes;
   char buf[BUFSIZ];
-#ifdef _FVWRITE_IN_STREAMIO
+#ifdef __FVWRITE_IN_STREAMIO
   struct __suio uio;
   struct __siov iov;
 
