@@ -89,13 +89,13 @@ ftello (
 
   /* Ensure stdio is set up.  */
 
-  CHECK_INIT (ptr, fp);
+  CHECK_INIT();
 
   _newlib_flockfile_start (fp);
 
   if (fp->_seek == NULL)
     {
-      _REENT_ERRNO(ptr) = ESPIPE;
+      errno = ESPIPE;
       _newlib_flockfile_exit (fp);
       return (_off_t) -1;
     }
