@@ -82,7 +82,7 @@ perror (
   int dummy;
   FILE *fp = stderr;
 
-  CHECK_INIT (ptr, fp);
+  CHECK_INIT();
 
   _newlib_flockfile_start(fp);
   fflush ( fp);
@@ -92,7 +92,7 @@ perror (
       WRITE_STR (": ");
     }
 
-  if ((error = _strerror_r (_REENT_ERRNO(ptr), 1, &dummy)) != NULL)
+  if ((error = _strerror_r (errno, 1, &dummy)) != NULL)
     WRITE_STR (error);
 
 #ifdef __SCLE
