@@ -1,7 +1,7 @@
 
 #include <picolibc.h>
 
-#ifndef _FVWRITE_IN_STREAMIO
+#ifndef __FVWRITE_IN_STREAMIO
 
 #include <stdio.h>
 #include <wchar.h>
