@@ -596,17 +596,5 @@ sprintf (
   return (ret);
 }
 
-#ifdef _NANO_FORMATTED_IO
-int
-siprintf (char *, const char *, ...)
-       _ATTRIBUTE ((__alias__("sprintf")));
-#endif
-
-#ifdef __LONG_DOUBLE_IEEE128__
-#if defined(_HAVE_ALIAS_ATTRIBUTE)
-#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
-#pragma GCC diagnostic ignored "-Wmissing-attributes"
-#endif
-__strong_reference(sprintf, __sprintfieee128);
-#endif
-#endif
+__nano_reference(sprintf, siprintf);
+__ieee128_reference(sprintf, __sprintfieee128);
