@@ -439,8 +439,4 @@ sscanf (const char *__restrict str,
   return ret;
 }
 
-#ifdef _NANO_FORMATTED_IO
-int __nonnull((1)) _NOTHROW
-siscanf (const char *, const char *, ...)
-       _ATTRIBUTE ((__alias__("sscanf")));
-#endif
+__nano_reference(sscanf, siscanf);
