@@ -1,7 +1,7 @@
 
 #include <picolibc.h>
 
-#ifdef _FVWRITE_IN_STREAMIO
+#ifdef __FVWRITE_IN_STREAMIO
 
 #include <stdio.h>
 #include <wchar.h>
