@@ -558,7 +558,7 @@ swprintf (wchar_t *__restrict str,
 
   if (size > INT_MAX / sizeof (wchar_t))
     {
-      _REENT_ERRNO(ptr) = EOVERFLOW;	/* POSIX extension */
+      errno = EOVERFLOW;	/* POSIX extension */
       return EOF;
     }
   f._flags = __SWR | __SSTR;
@@ -579,7 +579,7 @@ swprintf (wchar_t *__restrict str,
     /* _svfwprintf_r() returns how many wide characters it would have printed
      * if there were enough space.  Return an error if too big to fit in str,
      * unlike snprintf, which returns the size needed.  */
-    _REENT_ERRNO(ptr) = EOVERFLOW;	/* POSIX extension */
+    errno = EOVERFLOW;	/* POSIX extension */
     ret = -1;
   }
   return (ret);
