@@ -41,7 +41,7 @@ vasniprintf (
      for _size.  */
   if (len > INT_MAX)
     {
-      _REENT_ERRNO(ptr) = EOVERFLOW;
+      errno = EOVERFLOW;
       return NULL;
     }
   f._bf._size = f._w = len;
