@@ -41,7 +41,7 @@ vasnprintf (
      for _size.  */
   if (len > INT_MAX)
     {
-      _REENT_ERRNO(ptr) = EOVERFLOW;
+      errno = EOVERFLOW;
       return NULL;
     }
   f._bf._size = f._w = len;
@@ -54,8 +54,4 @@ vasnprintf (
   return (char *) f._bf._base;
 }
 
-#ifdef _NANO_FORMATTED_IO
-char *
-vasniprintf (char *, size_t *, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("vasnprintf")));
-#endif
+__nano_reference(vasnprintf, vasniprintf);
