@@ -47,8 +47,4 @@ vasprintf (
   return ret;
 }
 
-#ifdef _NANO_FORMATTED_IO
-int
-vasiprintf (char **, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("vasprintf")));
-#endif
+__nano_reference(vasprintf, vasiprintf);
