@@ -21,7 +21,6 @@ vdprintf (
   char buf[512];
   size_t n = sizeof buf;
 
-  _REENT_SMALL_CHECK_INIT (ptr);
   p = vasnprintf ( buf, &n, format, ap);
   if (!p)
     return -1;
@@ -31,8 +30,4 @@ vdprintf (
   return n;
 }
 
-#ifdef _NANO_FORMATTED_IO
-int
-vdiprintf (int, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("vdprintf")));
-#endif
+__nano_reference(vdprintf, vdiprintf);
