@@ -55,7 +55,7 @@
 Exactly one of IEEE_8087, IEEE_MC68k, VAX, or IBM should be defined.
 #endif
 
-#ifdef _WANT_IO_LONG_DOUBLE
+#ifdef __IO_LONG_DOUBLE
 /* If we are going to examine or modify specific bits in a long double using
    the lword0 or lwordx macros, then we must wrap the long double inside
    a union.  This is necessary to avoid undefined behavior according to
@@ -132,7 +132,7 @@ struct ldieee
 } __packed;
 #endif /* LDBL_MANT_DIG */
 #endif /* !IEEE_8087 */
-#endif /* _WANT_IO_LONG_DOUBLE */
+#endif /* __IO_LONG_DOUBLE */
 
 /* If we are going to examine or modify specific bits in a double using
    the word0 and/or word1 macros, then we must wrap the double inside
