@@ -101,6 +101,5 @@ int
 viprintf (const char *fmt,
        va_list ap)
 {
-  _REENT_SMALL_CHECK_INIT (reent);
-  return vfiprintf ( _stdout_r (reent), fmt, ap);
+  return vfiprintf ( stdout, fmt, ap);
 }
