@@ -48,8 +48,4 @@ vsprintf (
   return ret;
 }
 
-#ifdef _NANO_FORMATTED_IO
-int __nonnull((1)) _NOTHROW
-vsiprintf (char *, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("vsprintf")));
-#endif
+__nano_reference(vsprintf, vsiprintf);
