@@ -26,6 +26,5 @@ int
 vwprintf (const wchar_t *__restrict fmt,
        va_list ap)
 {
-  _REENT_SMALL_CHECK_INIT (reent);
-  return vfwprintf ( _stdout_r (reent), fmt, ap);
+  return vfwprintf ( stdout, fmt, ap);
 }
