@@ -28,9 +28,8 @@ wscanf(const wchar_t *__restrict fmt, ...)
   int ret;
   va_list ap;
 
-  _REENT_SMALL_CHECK_INIT (reent);
   va_start (ap, fmt);
-  ret = vfwscanf ( _stdin_r (reent), fmt, ap);
+  ret = vfwscanf ( stdin, fmt, ap);
   va_end (ap);
   return ret;
 }
