@@ -86,7 +86,7 @@ freopen64 (
   int e = 0;
 
 
-  CHECK_INIT (ptr, fp);
+  CHECK_INIT();
 
   /* We can't use the _newlib_flockfile_XXX macros here due to the
      interlocked locking with the sfp_lock. */
@@ -139,11 +139,11 @@ freopen64 (
   if (file != NULL)
     {
       f = open64 ((char *) file, oflags, 0666);
-      e = _REENT_ERRNO(ptr);
+      e = errno;
     }
   else
     {
-#ifdef _HAVE_FCNTL
+#ifdef __HAVE_FCNTL
       int oldflags;
       /*
        * Reuse the file descriptor, but only if the new access mode is
@@ -207,14 +207,12 @@ freopen64 (
     {				/* did not get it after all */
       __sfp_lock_acquire ();
       fp->_flags = 0;		/* set it free */
-      _REENT_ERRNO(ptr) = e;	/* restore in case _close clobbered */
+      errno = e;	/* restore in case _close clobbered */
       if (!(oflags2 & __SNLK))
 	_funlockfile (fp);
-#ifndef __SINGLE_THREAD__
       __lock_close_recursive (fp->_lock);
-#endif
       __sfp_lock_release ();
-#if !defined (__SINGLE_THREAD__) && defined (_POSIX_THREADS)
+#ifdef _STDIO_WITH_THREAD_CANCELLATION_SUPPORT
       pthread_setcancelstate (__oldcancel, &__oldcancel);
 #endif
       return NULL;
@@ -238,7 +236,7 @@ freopen64 (
 
   if (!(oflags2 & __SNLK))
     _funlockfile (fp);
-#if !defined (__SINGLE_THREAD__) && defined (_POSIX_THREADS)
+#ifdef _STDIO_WITH_THREAD_CANCELLATION_SUPPORT
   pthread_setcancelstate (__oldcancel, &__oldcancel);
 #endif
   return fp;
