@@ -8,10 +8,8 @@ All rights reserved.
 
 #include <stdlib.h>
 
-#ifndef _REENT_ONLY
 long
 atol (const char *s)
 {
   return strtol (s, NULL, 10);
 }
-#endif /* !_REENT_ONLY */
