@@ -43,7 +43,7 @@ Supporting OS subroutines required: <<_exit>>.
 #define _DEFAULT_SOURCE
 #include <stdlib.h>
 #include <unistd.h>	/* for _exit() declaration */
-#ifndef TINY_STDIO
+#ifndef __TINY_STDIO
 #include "../stdio/local.h"
 #include <stdio.h>
 #endif
@@ -56,18 +56,14 @@ Supporting OS subroutines required: <<_exit>>.
 void
 exit (int code)
 {
-#ifdef _LITE_EXIT
-  /* Refer to comments in __atexit.c for more details of lite exit.  */
-  void __call_exitprocs (int, void *) __attribute__((weak));
+  /* Refer to comments in __atexit.c and pico-onexit.c for why this is weak */
+  void __call_exitprocs (int, void *) __weak;
   if (__call_exitprocs)
-#endif
     __call_exitprocs (code, NULL);
 
-#ifndef TINY_STDIO
-  if (_REENT_CLEANUP(_GLOBAL_REENT))
-    (*_REENT_CLEANUP(_GLOBAL_REENT)) ();
-  if (__stdio_exit_handler != NULL)
-    (*__stdio_exit_handler) ();
+#ifndef __TINY_STDIO
+  if (_stdio_cleanup)
+    (*_stdio_cleanup) ();
 #endif
   _exit (code);
 }
