@@ -33,7 +33,7 @@ l64a (long value)
   char *result;
   int i, index;
   unsigned long tmp = (unsigned long)value & 0xffffffff;
-  static NEWLIB_THREAD_LOCAL char _l64a_buf[8];
+  static __THREAD_LOCAL char _l64a_buf[8];
 
   result = _l64a_buf;
   ptr = result;
