@@ -20,16 +20,16 @@ char *	_gcvt (double , int , char *, char, int);
 mbtowc_f __ascii_mbtowc;
 wctomb_f __ascii_wctomb;
 
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
 
 mbtowc_f __utf8_mbtowc;
 wctomb_f __utf8_wctomb;
 
-#ifdef _MB_EXTENDED_CHARSETS_ISO
+#ifdef __MB_EXTENDED_CHARSETS_ISO
 extern const uint16_t __iso_8859_conv[14][0x60];
 #endif
 
-#ifdef _MB_EXTENDED_CHARSETS_WINDOWS
+#ifdef __MB_EXTENDED_CHARSETS_WINDOWS
 extern const uint16_t __cp_conv[][0x80];
 #endif
 
