@@ -4,13 +4,11 @@ Copyright (c) 2002 Thomas Fitzsimmons <fitzsim@redhat.com>
 /* doc in mbsnrtowcs.c */
 
 #define _DEFAULT_SOURCE
-#include <newlib.h>
 #include <wchar.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
 
-#ifndef _REENT_ONLY
 size_t
 mbsrtowcs (wchar_t *__restrict dst,
 	const char **__restrict src,
@@ -19,4 +17,3 @@ mbsrtowcs (wchar_t *__restrict dst,
 {
   return mbsnrtowcs (dst, src, (size_t) -1, len, ps);
 }
-#endif /* !_REENT_ONLY */
