@@ -7,7 +7,6 @@ All rights reserved.
 #include "mbctype.h"
 #include <wchar.h>
 #include <string.h>
-#include <errno.h>
 #include <stdint.h>
 #include <endian.h>
 #include "local.h"
@@ -47,7 +46,7 @@ __ascii_mbtowc (
   return 1;
 }
 
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
 
 /* we override the mbstate_t __count field for more complex encodings and use it store a state value */
 #define __state __count
@@ -249,6 +248,8 @@ __utf8_mbtowc (
   return -1;
 }
 
+#ifdef __MB_EXTENDED_CHARSETS_UCS
+
 #if _BYTE_ORDER == _LITTLE_ENDIAN
 #define __ucs2le_mbtowc __ucs2_mbtowc
 #define __ucs2be_mbtowc __ucs2swap_mbtowc
@@ -329,7 +330,9 @@ __ucs4swap_mbtowc (
     return 4;
 }
 
-#ifdef _MB_EXTENDED_CHARSETS_ISO
+#endif /* __MB_EXTENDED_CHARSETS_UCS */
+
+#ifdef __MB_EXTENDED_CHARSETS_ISO
 static int
 ___iso_mbtowc (wchar_t *pwc, const char *s, size_t n,
 	       enum locale_id id, mbstate_t *state)
@@ -473,9 +476,9 @@ __iso_8859_16_mbtowc (wchar_t *pwc, const char *s, size_t n,
   return ___iso_mbtowc (pwc, s, n, locale_ISO_8859_16, state);
 }
 
-#endif /* _MB_EXTENDED_CHARSETS_ISO */
+#endif /* __MB_EXTENDED_CHARSETS_ISO */
 
-#ifdef _MB_EXTENDED_CHARSETS_WINDOWS
+#ifdef __MB_EXTENDED_CHARSETS_WINDOWS
 
 static int
 ___cp_mbtowc (wchar_t *pwc, const char *s, size_t n,
@@ -699,9 +702,9 @@ __cp_103_mbtowc (wchar_t *pwc, const char *s, size_t n,
   return ___cp_mbtowc (pwc, s, n, locale_KOI8_T, state);
 }
 
-#endif /* _MB_EXTENDED_CHARSETS_WINDOWS */
+#endif /* __MB_EXTENDED_CHARSETS_WINDOWS */
 
-#ifdef _MB_EXTENDED_CHARSETS_JIS
+#ifdef __MB_EXTENDED_CHARSETS_JIS
 
 typedef enum __packed { ESCAPE, DOLLAR, BRACKET, AT, B, J,
                NUL, JIS_CHAR, OTHER, JIS_C_NUM } JIS_CHAR_TYPE;
@@ -716,7 +719,7 @@ typedef enum __packed { COPY_A, COPY_J1, COPY_J2, MAKE_A, NOOP, EMPTY, ERROR } J
  * is 2 (switch to JIS) + 2 (JIS characters) + 2 (switch back to ASCII) = 6.
  *************************************************************************************/
 
-static JIS_STATE JIS_state_table[JIS_S_NUM][JIS_C_NUM] = {
+static const JIS_STATE JIS_state_table[JIS_S_NUM][JIS_C_NUM] = {
 /*              ESCAPE   DOLLAR    BRACKET   AT       B       J        NUL      JIS_CHAR  OTHER */
 /* ASCII */   { A_ESC,   ASCII,    ASCII,    ASCII,   ASCII,  ASCII,   ASCII,   ASCII,    ASCII },
 /* JIS */     { J_ESC,   JIS_1,    JIS_1,    JIS_1,   JIS_1,  JIS_1,   INV,     JIS_1,    INV },
@@ -727,7 +730,7 @@ static JIS_STATE JIS_state_table[JIS_S_NUM][JIS_C_NUM] = {
 /* J_ESC_BR */{ INV,     INV,      INV,      INV,     ASCII,  ASCII,   INV,     INV,      INV },
 };
 
-static JIS_ACTION JIS_action_table[JIS_S_NUM][JIS_C_NUM] = {
+static const JIS_ACTION JIS_action_table[JIS_S_NUM][JIS_C_NUM] = {
 /*              ESCAPE   DOLLAR    BRACKET   AT       B        J        NUL      JIS_CHAR  OTHER */
 /* ASCII */   { NOOP,    COPY_A,   COPY_A,   COPY_A,  COPY_A,  COPY_A,  EMPTY,   COPY_A,  COPY_A},
 /* JIS */     { NOOP,    COPY_J1,  COPY_J1,  COPY_J1, COPY_J1, COPY_J1, ERROR,   COPY_J1, ERROR },
@@ -1014,18 +1017,20 @@ __jis_mbtowc (
   state->__state = curr_state;
   return -2;  /* n < bytes needed */
 }
-#endif /* _MB_EXTENDED_CHARSETS_JIS */
+#endif /* __MB_EXTENDED_CHARSETS_JIS */
 
 const mbtowc_p __mbtowc[locale_END - locale_BASE] = {
     [locale_C - locale_BASE] = __ascii_mbtowc,
     [locale_UTF_8 - locale_BASE] = __utf8_mbtowc,
+#ifdef __MB_EXTENDED_CHARSETS_UCS
     [locale_UCS_2 - locale_BASE] = __ucs2_mbtowc,
     [locale_UCS_2LE - locale_BASE] = __ucs2le_mbtowc,
     [locale_UCS_2BE - locale_BASE] = __ucs2be_mbtowc,
     [locale_UCS_4 - locale_BASE] = __ucs4_mbtowc,
     [locale_UCS_4LE - locale_BASE] = __ucs4le_mbtowc,
     [locale_UCS_4BE - locale_BASE] = __ucs4be_mbtowc,
-#ifdef _MB_EXTENDED_CHARSETS_ISO
+#endif
+#ifdef __MB_EXTENDED_CHARSETS_ISO
     [locale_ISO_8859_1 - locale_BASE] = __iso_8859_1_mbtowc,
     [locale_ISO_8859_2 - locale_BASE] = __iso_8859_2_mbtowc,
     [locale_ISO_8859_3 - locale_BASE] = __iso_8859_3_mbtowc,
@@ -1042,7 +1047,7 @@ const mbtowc_p __mbtowc[locale_END - locale_BASE] = {
     [locale_ISO_8859_15 - locale_BASE] = __iso_8859_15_mbtowc,
     [locale_ISO_8859_16 - locale_BASE] = __iso_8859_16_mbtowc,
 #endif
-#ifdef _MB_EXTENDED_CHARSETS_WINDOWS
+#ifdef __MB_EXTENDED_CHARSETS_WINDOWS
     [locale_CP437 - locale_BASE] = __cp_437_mbtowc,
     [locale_CP720 - locale_BASE] = __cp_720_mbtowc,
     [locale_CP737 - locale_BASE] = __cp_737_mbtowc,
@@ -1071,11 +1076,11 @@ const mbtowc_p __mbtowc[locale_END - locale_BASE] = {
     [locale_PT154 - locale_BASE] = __cp_102_mbtowc,
     [locale_KOI8_T - locale_BASE] = __cp_103_mbtowc,
 #endif
-#ifdef _MB_EXTENDED_CHARSETS_JIS
+#ifdef __MB_EXTENDED_CHARSETS_JIS
     [locale_JIS - locale_BASE] = __jis_mbtowc,
     [locale_EUCJP - locale_BASE] = __eucjp_mbtowc,
     [locale_SJIS - locale_BASE] = __sjis_mbtowc,
 #endif
 };
 
-#endif /* _MB_CAPABLE */
+#endif /* __MB_CAPABLE */
