@@ -48,7 +48,7 @@ struct _rand48 {
   unsigned short _add;
 };
 
-extern NEWLIB_THREAD_LOCAL struct _rand48 _rand48;
+extern __THREAD_LOCAL struct _rand48 _rand48;
 
 extern void __dorand48 (struct _rand48 *r, unsigned short[3]);
 
