@@ -278,11 +278,11 @@ strtod_l (const char *__restrict s00, char **__restrict se,
 	for(s = s00;;s++) switch(*s) {
 		case '-':
 			sign = 1;
-                        __PICOLIBC_FALLTHROUGH;
+                        __fallthrough;
 		case '+':
 			if (*++s)
 				goto break2;
-                        __PICOLIBC_FALLTHROUGH;
+                        __fallthrough;
 		case 0:
 			goto ret0;
 		case '\t':
@@ -323,7 +323,7 @@ strtod_l (const char *__restrict s00, char **__restrict se,
 			  case STRTOG_NoNumber:
 				s = s00;
 				sign = 0;
-				__PICOLIBC_FALLTHROUGH;
+				__fallthrough;
 			  case STRTOG_Zero:
 				break;
 			  default:
@@ -399,7 +399,7 @@ strtod_l (const char *__restrict s00, char **__restrict se,
 		switch(c = *++s) {
 			case '-':
 				esign = 1;
-                                __PICOLIBC_FALLTHROUGH;
+                                __fallthrough;
 			case '+':
 				c = *++s;
 			}
@@ -597,7 +597,7 @@ strtod_l (const char *__restrict s00, char **__restrict se,
 			if (e1 > DBL_MAX_10_EXP) {
  ovfl:
 #ifndef NO_ERRNO
-				_REENT_ERRNO(ptr) = ERANGE;
+				errno = ERANGE;
 #endif
 				/* Can't trust HUGE_VAL */
 #ifdef IEEE_Arith
@@ -704,7 +704,7 @@ strtod_l (const char *__restrict s00, char **__restrict se,
  undfl:
 					dval(rv) = 0.;
 #ifndef NO_ERRNO
-					_REENT_ERRNO(ptr) = ERANGE;
+					errno = ERANGE;
 #endif
 					if (bd0)
 						goto retfree;
@@ -1251,7 +1251,7 @@ strtod_l (const char *__restrict s00, char **__restrict se,
 #ifndef NO_ERRNO
 		/* try to avoid the bug of testing an 8087 register value */
 		if ((dword0(rv) & Exp_mask) == 0)
-			_REENT_ERRNO(ptr) = ERANGE;
+			errno = ERANGE;
 #endif
 		}
 #endif /* Avoid_Underflow */
@@ -1281,8 +1281,8 @@ strtod (const char *__restrict s00,
   return strtod_l (s00, se, __get_current_locale ());
 }
 
-#if defined(_HAVE_LONG_DOUBLE) && defined(_LDBL_EQ_DBL)
-#ifdef _HAVE_ALIAS_ATTRIBUTE
+#if defined(__HAVE_LONG_DOUBLE) && defined(_LDBL_EQ_DBL)
+#ifdef __strong_reference
 #ifdef __GNUCLIKE_PRAGMA_DIAGNOSTIC
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wunknown-warning-option"
@@ -1329,7 +1329,7 @@ strtof_l (const char *__restrict s00, char **__restrict se, locale_t loc)
   float retval = (float) val;
 #ifndef NO_ERRNO
   if ((isinf (retval) && !isinf (val)) || (isdenormf(retval) && !isdenorm(val)))
-    _REENT_ERRNO(_REENT) = ERANGE;
+    errno = ERANGE;
 #endif
   return retval;
 }
@@ -1344,7 +1344,7 @@ strtof (const char *__restrict s00,
   float retval = (float) val;
 #ifndef NO_ERRNO
   if ((isinf (retval) && !isinf (val)) || (isdenormf(retval) && !isdenorm(val)))
-    _REENT_ERRNO(_REENT) = ERANGE;
+    errno = ERANGE;
 #endif
   return retval;
 }
