@@ -4,10 +4,8 @@ Copyright (c) 2002 Thomas Fitzsimmons <fitzsim@redhat.com>
 /* Doc in wcsnrtombs.c */
 
 #define _DEFAULT_SOURCE
-#include <newlib.h>
 #include <wchar.h>
 
-#ifndef _REENT_ONLY
 size_t
 wcsrtombs (char *__restrict dst,
 	const wchar_t **__restrict src,
@@ -16,4 +14,3 @@ wcsrtombs (char *__restrict dst,
 {
   return wcsnrtombs (dst, src, (size_t) -1, len, ps);
 }
-#endif /* !_REENT_ONLY */
