@@ -37,7 +37,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #include "local.h"
 #include "local.h"
 
-#if defined(_HAVE_LONG_DOUBLE) && __LDBL_MANT_DIG == 64
+#if defined(__HAVE_LONG_DOUBLE) && __LDBL_MANT_DIG == 64
 
 long double
 wcstold_l (const wchar_t *__restrict nptr, wchar_t **__restrict endptr,
@@ -125,4 +125,4 @@ wcstold (const wchar_t *__restrict nptr, wchar_t **__restrict endptr)
 #endif
 }
 
-#endif /* _HAVE_LONG_DOUBLE && __LDBL_MANT_DIG == 64 */
+#endif /* __HAVE_LONG_DOUBLE && __LDBL_MANT_DIG == 64 */
