@@ -125,7 +125,6 @@ No supporting OS subroutines are required.
 /*
  * Convert a wide string to a long long integer.
  */
-#ifndef _REENT_ONLY
 
 long long
 wcstoll_l (const wchar_t *nptr, wchar_t **endptr,
@@ -137,6 +136,13 @@ wcstoll_l (const wchar_t *nptr, wchar_t **endptr,
 	register unsigned long long cutoff;
 	register int neg = 0, any, cutlim;
 
+        /* Check for invalid base value */
+        if ((unsigned) base > 36 || base == 1) {
+                errno = EINVAL;
+                if (endptr)
+                        *endptr = (wchar_t *) nptr;
+                return 0;
+        }
 	/*
 	 * Skip white space and pick up leading +/- sign if any.
 	 * If base is 0, allow 0x for hex and 0 for octal, else
@@ -153,6 +159,7 @@ wcstoll_l (const wchar_t *nptr, wchar_t **endptr,
 	if ((base == 0 || base == 16) &&
 	    c == L'0' && (*s == L'x' || *s == L'X')) {
 		c = s[1];
+                nptr = s;
 		s += 2;
 		base = 16;
 	}
@@ -200,7 +207,7 @@ wcstoll_l (const wchar_t *nptr, wchar_t **endptr,
 	}
 	if (any < 0) {
 		acc = neg ? LLONG_MIN : LLONG_MAX;
-		_REENT_ERRNO(rptr) = ERANGE;
+		errno = ERANGE;
 	} else if (neg)
 		acc = -acc;
 	if (endptr != 0)
@@ -216,4 +223,3 @@ wcstoll (const wchar_t *__restrict s,
 	return wcstoll_l (s, ptr, base, __get_current_locale ());
 }
 
-#endif
