@@ -51,7 +51,6 @@ static char sccsid[] = "from @(#)strtoul.c	8.1 (Berkeley) 6/4/93";
  * Convert a wide character string to a uintmax_t integer.
  */
 
-#ifndef _REENT_ONLY
 uintmax_t
 wcstoumax_l(const wchar_t * __restrict nptr,
 	     wchar_t ** __restrict endptr, int base, locale_t loc)
@@ -62,6 +61,13 @@ wcstoumax_l(const wchar_t * __restrict nptr,
 	uintmax_t cutoff;
 	int neg = 0, any, cutlim;
 
+        /* Check for invalid base value */
+        if ((unsigned) base > 36 || base == 1) {
+                errno = EINVAL;
+                if (endptr)
+                        *endptr = (wchar_t *) nptr;
+                return 0;
+        }
 	/*
 	 * See strtoimax for comments as to the logic used.
 	 */
@@ -79,6 +85,7 @@ wcstoumax_l(const wchar_t * __restrict nptr,
 	if ((base == 0 || base == 16) &&
 	    c == L'0' && (*s == L'x' || *s == L'X')) {
 		c = s[1];
+                nptr = s;
 		s += 2;
 		base = 16;
 	}
@@ -116,10 +123,10 @@ wcstoumax_l(const wchar_t * __restrict nptr,
 	}
 	if (any < 0) {
 		acc = UINTMAX_MAX;
-		_REENT_ERRNO(rptr) = ERANGE;
+		errno = ERANGE;
 	} else if (!any) {
 noconv:
-		_REENT_ERRNO(rptr) = EINVAL;
+		errno = EINVAL;
 	} else if (neg)
 		acc = -acc;
 	if (endptr != NULL)
@@ -133,4 +140,3 @@ wcstoumax(const wchar_t* __restrict nptr, wchar_t** __restrict endptr, int base)
 	return wcstoumax_l(nptr, endptr, base, __get_current_locale());
 }
 
-#endif
