@@ -30,7 +30,7 @@ __ascii_wctomb (
   return 1;
 }
 
-#ifdef _MB_CAPABLE
+#ifdef __MB_CAPABLE
 
 /* for some conversions, we use the __count field as a place to store a state value */
 #define __state __count
@@ -41,43 +41,47 @@ __utf8_wctomb (
         wchar_t        wchar,
         mbstate_t     *state)
 {
-  int ret = 0;
-
   (void) state;         /* unused when wchar_t is 32-bits */
   if (s == NULL)
-    return 0; /* UTF-8 encoding is not state-dependent */
+    {
+#if __SIZEOF_WCHAR_T__ == 2
+      state->__count = 0;       /* UTF-16 encoding is state-dependent */
+#endif
+      return 0;
+    }
 
 #if __SIZEOF_WCHAR_T__ == 2
-  if (state->__count == -4 && (wchar < 0xdc00 || wchar > 0xdfff))
+  if (state->__count == -4)
     {
-      /* Unexpected extra high surrogate */
-      if (0xd800 <= wchar && wchar <= 0xdbff)
-        {
-          return -1;
-        }
-      /* There's a leftover lone high surrogate.  Write out the CESU-8 value
-	 of the surrogate and proceed to convert the given character.  Note
-	 to return extra 3 bytes. */
-      uint32_t tmp;
-      tmp = ((uint32_t) state->__value.__wchb[0] << 16 | (uint32_t) state->__value.__wchb[1] << 8)
-          - ((uint32_t) 0x10000 >> 10 | (uint32_t) 0xd80d);
-      *s++ = 0xe0 | ((tmp & 0xf000) >> 12);
-      *s++ = 0x80 | ((tmp &  0xfc0) >> 6);
-      *s++ = 0x80 |  (tmp &   0x3f);
       state->__count = 0;
-      ret = 3;
+      /* Check for low surrogate */
+      if (0xdc00 <= wchar && wchar <= 0xdfff)
+        {
+            uint32_t tmp;
+            /* Second half of a surrogate pair.  Reconstruct the full
+               Unicode value and return the trailing three bytes of the
+               UTF-8 character. */
+            tmp = state->__value.__ucs | (wchar & 0x3ff);
+            *s++ = 0xf0 | ((tmp & 0x1c0000) >> 18);
+            *s++ = 0x80 | ((tmp &  0x3f000) >> 12);
+            *s++ = 0x80 | ((tmp &    0xfc0) >> 6);
+            *s   = 0x80 |  (tmp &     0x3f);
+            return 4;
+        }
+      /* Not a low surrogate */
+      return -1;
     }
 #endif
   if (wchar <= 0x7f)
     {
       *s = wchar;
-      return ret + 1;
+      return 1;
     }
   if (wchar >= 0x80 && wchar <= 0x7ff)
     {
       *s++ = 0xc0 | ((wchar & 0x7c0) >> 6);
       *s   = 0x80 |  (wchar &  0x3f);
-      return ret + 2;
+      return 2;
     }
   if (wchar >= 0x800
 #if __SIZEOF_WCHAR_T__ > 2
@@ -88,49 +92,22 @@ __utf8_wctomb (
       if (wchar >= 0xd800 && wchar <= 0xdfff)
 	{
 #if __SIZEOF_WCHAR_T__ == 2
-            uint32_t tmp;
-            if (wchar <= 0xdbff)
+          if (wchar <= 0xdbff)
             {
-                if (state->__count == -4)
-                {
-                    /* Extra high surrogate */
-                    return -1;
-                }
-                /* First half of a surrogate pair.  Store the state and
-                   return ret + 0. */
-                tmp = ((wchar & 0x3ff) << 10) + 0x10000;
-                state->__value.__wchb[0] = (tmp >> 16) & 0xff;
-                state->__value.__wchb[1] = (tmp >> 8) & 0xff;
-                state->__count = -4;
-                *s = (0xf0 | ((tmp & 0x1c0000) >> 18));
-                return ret;
+              /* First half of a surrogate pair.  Store the state and
+                 return 0. */
+              state->__value.__ucs = ((uint32_t) (wchar & 0x3ff) << 10) + 0x10000;
+              state->__count = -4;
+              return 0;
             }
-            if (state->__count == -4)
-            {
-                /* Second half of a surrogate pair.  Reconstruct the full
-                   Unicode value and return the trailing three bytes of the
-                   UTF-8 character. */
-                tmp = ((uint32_t) state->__value.__wchb[0] << 16)
-                    | (state->__value.__wchb[1] << 8)
-                    | (wchar & 0x3ff);
-                state->__count = 0;
-                *s++ = 0xf0 | ((tmp & 0x1c0000) >> 18);
-                *s++ = 0x80 | ((tmp &  0x3f000) >> 12);
-                *s++ = 0x80 | ((tmp &    0xfc0) >> 6);
-                *s   = 0x80 |  (tmp &     0x3f);
-                return 4;
-            }
-            /* Unexpected second half */
-            return -1;
-#else
-            /* No UTF-16 surrogate handling in UCS-4 */
-            return -1;
 #endif
+          /* Unexpected surrogate */
+          return -1;
 	}
       *s++ = 0xe0 | ((wchar & 0xf000) >> 12);
       *s++ = 0x80 | ((wchar &  0xfc0) >> 6);
       *s   = 0x80 |  (wchar &   0x3f);
-      return ret + 3;
+      return 3;
     }
 #if __SIZEOF_WCHAR_T__ == 4
   if (wchar >= (wchar_t) 0x10000 && wchar <= (wchar_t) 0x10ffff)
@@ -146,6 +123,8 @@ __utf8_wctomb (
   return -1;
 }
 
+#ifdef __MB_EXTENDED_CHARSETS_UCS
+
 #if _BYTE_ORDER == _LITTLE_ENDIAN
 #define __ucs2le_wctomb __ucs2_wctomb
 #define __ucs2be_wctomb __ucs2swap_wctomb
@@ -226,7 +205,9 @@ __ucs4swap_wctomb (
     return 4;
 }
 
-#ifdef _MB_EXTENDED_CHARSETS_JIS
+#endif /* __MB_EXTENDED_CHARSETS_UCS */
+
+#ifdef __MB_EXTENDED_CHARSETS_JIS
 
 static int
 __sjis_wctomb (
@@ -347,9 +328,9 @@ __jis_wctomb (
   *s = (char)char2;
   return cnt + 1;
 }
-#endif /* _MB_EXTENDED_CHARSETS_JIS */
+#endif /* __MB_EXTENDED_CHARSETS_JIS */
 
-#ifdef _MB_EXTENDED_CHARSETS_ISO
+#ifdef __MB_EXTENDED_CHARSETS_ISO
 
 static int
 ___iso_wctomb (char *s, wchar_t _wchar, enum locale_id id,
@@ -484,9 +465,9 @@ static int __iso_8859_16_wctomb (char *s, wchar_t _wchar,
   return ___iso_wctomb (s, _wchar, locale_ISO_8859_16, state);
 }
 
-#endif /* _MB_EXTENDED_CHARSETS_ISO */
+#endif /* __MB_EXTENDED_CHARSETS_ISO */
 
-#ifdef _MB_EXTENDED_CHARSETS_WINDOWS
+#ifdef __MB_EXTENDED_CHARSETS_WINDOWS
 
 static int
 ___cp_wctomb (char *s, wchar_t _wchar, int cp_idx,
@@ -685,18 +666,20 @@ __cp_103_wctomb (char *s, wchar_t _wchar, mbstate_t *state)
   return ___cp_wctomb (s, _wchar, 26, state);
 }
 
-#endif /* _MB_EXTENDED_CHARSETS_WINDOWS */
+#endif /* __MB_EXTENDED_CHARSETS_WINDOWS */
 
 const wctomb_p __wctomb[locale_END - locale_BASE] = {
     [locale_C - locale_BASE] = __ascii_wctomb,
     [locale_UTF_8 - locale_BASE] = __utf8_wctomb,
+#ifdef __MB_EXTENDED_CHARSETS_UCS
     [locale_UCS_2 - locale_BASE] = __ucs2_wctomb,
     [locale_UCS_2LE - locale_BASE] = __ucs2le_wctomb,
     [locale_UCS_2BE - locale_BASE] = __ucs2be_wctomb,
     [locale_UCS_4 - locale_BASE] = __ucs4_wctomb,
     [locale_UCS_4LE - locale_BASE] = __ucs4le_wctomb,
     [locale_UCS_4BE - locale_BASE] = __ucs4be_wctomb,
-#ifdef _MB_EXTENDED_CHARSETS_ISO
+#endif
+#ifdef __MB_EXTENDED_CHARSETS_ISO
     [locale_ISO_8859_1 - locale_BASE] = __iso_8859_1_wctomb,
     [locale_ISO_8859_2 - locale_BASE] = __iso_8859_2_wctomb,
     [locale_ISO_8859_3 - locale_BASE] = __iso_8859_3_wctomb,
@@ -713,7 +696,7 @@ const wctomb_p __wctomb[locale_END - locale_BASE] = {
     [locale_ISO_8859_15 - locale_BASE] = __iso_8859_15_wctomb,
     [locale_ISO_8859_16 - locale_BASE] = __iso_8859_16_wctomb,
 #endif
-#ifdef _MB_EXTENDED_CHARSETS_WINDOWS
+#ifdef __MB_EXTENDED_CHARSETS_WINDOWS
     [locale_CP437 - locale_BASE] = __cp_437_wctomb,
     [locale_CP720 - locale_BASE] = __cp_720_wctomb,
     [locale_CP737 - locale_BASE] = __cp_737_wctomb,
@@ -742,11 +725,11 @@ const wctomb_p __wctomb[locale_END - locale_BASE] = {
     [locale_PT154 - locale_BASE] = __cp_102_wctomb,
     [locale_KOI8_T - locale_BASE] = __cp_103_wctomb,
 #endif
-#ifdef _MB_EXTENDED_CHARSETS_JIS
+#ifdef __MB_EXTENDED_CHARSETS_JIS
     [locale_JIS - locale_BASE] = __jis_wctomb,
     [locale_EUCJP - locale_BASE] = __eucjp_wctomb,
     [locale_SJIS - locale_BASE] = __sjis_wctomb,
 #endif
 };
 
-#endif /* _MB_CAPABLE */
+#endif /* __MB_CAPABLE */
