@@ -47,8 +47,8 @@ strcasecmp_l (const char *s1, const char *s2, locale_t locale)
   int d = 0;
   for ( ; ; )
     {
-      const int c1 = tolower_l (*s1++, locale);
-      const int c2 = tolower_l (*s2++, locale);
+      const int c1 = tolower_l (*(unsigned char*)s1++, locale);
+      const int c2 = tolower_l (*(unsigned char*)s2++, locale);
       if (((d = c1 - c2) != 0) || (c2 == '\0'))
         break;
     }
