@@ -45,28 +45,7 @@ QUICKREF
 
 #include <string.h>
 #include <limits.h>
-#include <stdint.h>
-
-/* Nonzero if X is not aligned on a "long" boundary.  */
-#define UNALIGNED(X) ((uintptr_t)X & (sizeof (long) - 1))
-
-/* How many bytes are loaded each iteration of the word copy loop.  */
-#define LBLOCKSIZE (sizeof (long))
-
-#if LONG_MAX == 2147483647L
-#define DETECTNULL(X) (((X) - 0x01010101) & ~(X) & 0x80808080)
-#else
-#if LONG_MAX == 9223372036854775807L
-/* Nonzero if X (a long int) contains a NULL byte. */
-#define DETECTNULL(X) (((X) - 0x0101010101010101) & ~(X) & 0x8080808080808080)
-#else
-#error long int is not a 32bit or 64bit type.
-#endif
-#endif
-
-/* DETECTCHAR returns nonzero if (long)X contains the byte used
-   to fill (long)MASK. */
-#define DETECTCHAR(X,MASK) (DETECTNULL(X ^ MASK))
+#include "local.h"
 
 char *
 strchr (const char *s1,
@@ -75,15 +54,15 @@ strchr (const char *s1,
   const unsigned char *s = (const unsigned char *)s1;
   unsigned char c = i;
 
-#if !defined(PREFER_SIZE_OVER_SPEED) && !defined(__OPTIMIZE_SIZE__) && \
-    !defined(PICOLIBC_NO_OUT_OF_BOUNDS_READS)
+#if !defined(__PREFER_SIZE_OVER_SPEED) && !defined(__OPTIMIZE_SIZE__) && \
+    !defined(_PICOLIBC_NO_OUT_OF_BOUNDS_READS)
   unsigned long mask,j;
   unsigned long *aligned_addr;
 
   /* Special case for finding 0.  */
   if (!c)
     {
-      while (UNALIGNED (s))
+      while (UNALIGNED_X(s))
         {
           if (!*s)
             return (char *) s;
@@ -91,7 +70,7 @@ strchr (const char *s1,
         }
       /* Operate a word at a time.  */
       aligned_addr = (unsigned long *) s;
-      while (!DETECTNULL (*aligned_addr))
+      while (!DETECT_NULL(*aligned_addr))
         aligned_addr++;
       /* Found the end of string.  */
       s = (const unsigned char *) aligned_addr;
@@ -101,7 +80,7 @@ strchr (const char *s1,
     }
 
   /* All other bytes.  Align the pointer, then search a long at a time.  */
-  while (UNALIGNED (s))
+  while (UNALIGNED_X(s))
     {
       if (!*s)
         return NULL;
@@ -111,11 +90,11 @@ strchr (const char *s1,
     }
 
   mask = c;
-  for (j = 8; j < LBLOCKSIZE * 8; j <<= 1)
+  for (j = 8; j < sizeof(mask) * 8; j <<= 1)
     mask = (mask << j) | mask;
 
   aligned_addr = (unsigned long *) s;
-  while (!DETECTNULL (*aligned_addr) && !DETECTCHAR (*aligned_addr, mask))
+  while (!DETECT_NULL(*aligned_addr) && !DETECT_CHAR(*aligned_addr, mask))
     aligned_addr++;
 
   /* The block of bytes currently pointed to by aligned_addr
@@ -124,7 +103,7 @@ strchr (const char *s1,
 
   s = (unsigned char *) aligned_addr;
 
-#endif /* not PREFER_SIZE_OVER_SPEED */
+#endif /* not __PREFER_SIZE_OVER_SPEED */
 
   while (*s && *s != c)
     s++;
