@@ -44,7 +44,7 @@ QUICKREF
 #include <string.h>
 
 int
-strcoll_l (const char *a, const char *b, struct __locale_t *locale)
+strcoll_l (const char *a, const char *b, locale_t locale)
 {
   (void) locale;
   return strcmp (a, b);
