@@ -44,38 +44,19 @@ QUICKREF
 
 #include <string.h>
 #include <limits.h>
-#include <stdint.h>
+#include "local.h"
 
 /*SUPPRESS 560*/
 /*SUPPRESS 530*/
 
-/* Nonzero if either X or Y is not aligned on a "long" boundary.  */
-#define UNALIGNED(X, Y) \
-  (((uintptr_t)X & (sizeof (long) - 1)) | ((uintptr_t)Y & (sizeof (long) - 1)))
-
-#if LONG_MAX == 2147483647L
-#define DETECTNULL(X) (((X) - 0x01010101) & ~(X) & 0x80808080)
-#else
-#if LONG_MAX == 9223372036854775807L
-/* Nonzero if X (a long int) contains a NULL byte. */
-#define DETECTNULL(X) (((X) - 0x0101010101010101) & ~(X) & 0x8080808080808080)
-#else
-#error long int is not a 32bit or 64bit type.
-#endif
-#endif
-
-#ifndef DETECTNULL
-#error long int is not a 32bit or 64bit byte
-#endif
-
 #undef strcpy
 
 char*
 strcpy (char *dst0,
 	const char *src0)
 {
-#if defined(PREFER_SIZE_OVER_SPEED) || defined(__OPTIMIZE_SIZE__) || \
-    defined(PICOLIBC_NO_OUT_OF_BOUNDS_READS)
+#if defined(__PREFER_SIZE_OVER_SPEED) || defined(__OPTIMIZE_SIZE__) || \
+    defined(_PICOLIBC_NO_OUT_OF_BOUNDS_READS)
   char *s = dst0;
 
   while ((*dst0++ = *src0++))
@@ -89,14 +70,14 @@ strcpy (char *dst0,
   const long *aligned_src;
 
   /* If SRC or DEST is unaligned, then copy bytes.  */
-  if (!UNALIGNED (src, dst))
+  if (!UNALIGNED_X_Y(src, dst))
     {
       aligned_dst = (long*)dst;
       aligned_src = (long*)src;
 
       /* SRC and DEST are both "long int" aligned, try to do "long int"
          sized copies.  */
-      while (!DETECTNULL(*aligned_src))
+      while (!DETECT_NULL(*aligned_src))
         {
           *aligned_dst++ = *aligned_src++;
         }
@@ -108,5 +89,5 @@ strcpy (char *dst0,
   while ((*dst++ = *src++))
     ;
   return dst0;
-#endif /* not PREFER_SIZE_OVER_SPEED */
+#endif /* not __PREFER_SIZE_OVER_SPEED */
 }
