@@ -17,7 +17,7 @@ WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 /*
 FUNCTION
 	<<strncmp>>---character string compare
-	
+
 INDEX
 	strncmp
 
@@ -47,34 +47,15 @@ QUICKREF
 
 #include <string.h>
 #include <limits.h>
-#include <stdint.h>
+#include "local.h"
 
-/* Nonzero if either X or Y is not aligned on a "long" boundary.  */
-#define UNALIGNED(X, Y) \
-  (((uintptr_t)X & (sizeof (long) - 1)) | ((uintptr_t)Y & (sizeof (long) - 1)))
-
-/* DETECTNULL returns nonzero if (long)X contains a NULL byte. */
-#if LONG_MAX == 2147483647L
-#define DETECTNULL(X) (((X) - 0x01010101) & ~(X) & 0x80808080)
-#else
-#if LONG_MAX == 9223372036854775807L
-#define DETECTNULL(X) (((X) - 0x0101010101010101) & ~(X) & 0x8080808080808080)
-#else
-#error long int is not a 32bit or 64bit type.
-#endif
-#endif
-
-#ifndef DETECTNULL
-#error long int is not a 32bit or 64bit byte
-#endif
-
-int 
+int
 strncmp (const char *s1,
 	const char *s2,
 	size_t n)
 {
-#if defined(PREFER_SIZE_OVER_SPEED) || defined(__OPTIMIZE_SIZE__) || \
-    defined(PICOLIBC_NO_OUT_OF_BOUNDS_READS)
+#if defined(__PREFER_SIZE_OVER_SPEED) || defined(__OPTIMIZE_SIZE__) || \
+    defined(_PICOLIBC_NO_OUT_OF_BOUNDS_READS)
   if (n == 0)
     return 0;
 
@@ -95,7 +76,7 @@ strncmp (const char *s1,
     return 0;
 
   /* If s1 or s2 are unaligned, then compare bytes. */
-  if (!UNALIGNED (s1, s2))
+  if (!UNALIGNED_X_Y(s1, s2))
     {
       /* If s1 and s2 are word-aligned, compare them a word at a time. */
       a1 = (unsigned long*)s1;
@@ -106,7 +87,7 @@ strncmp (const char *s1,
 
           /* If we've run out of bytes or hit a null, return zero
 	     since we already know *a1 == *a2.  */
-          if (n == 0 || DETECTNULL (*a1))
+          if (n == 0 || DETECT_NULL (*a1))
 	    return 0;
 
           a1++;
@@ -128,5 +109,5 @@ strncmp (const char *s1,
       s2++;
     }
   return (*(unsigned char *) s1) - (*(unsigned char *) s2);
-#endif /* not PREFER_SIZE_OVER_SPEED */
+#endif /* not __PREFER_SIZE_OVER_SPEED */
 }
