@@ -50,12 +50,8 @@ ANSI C requires <<ctime>>.
 
 #include <time.h>
 
-#ifndef _REENT_ONLY
-
 char *
 ctime (const time_t * tim_p)
 {
   return asctime (localtime (tim_p));
 }
-
-#endif
