@@ -30,9 +30,18 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-#define PICOLIBC_FLOAT_PRINTF_SCANF
+#define _NEED_IO_FLOAT
 
-#include "dtoa_engine.h"
+#include "dtoa.h"
+
+#if __GNUC__ == 12 && __GNUC_MINOR__ == 2 && __GNUC_PATCHLEVEL__ == 1 && __OPTIMIZE_SIZE__
+/*
+ * GCC 12.2.1 has a bug in -Os mode on (at least) arm v8.1-m which
+ * mis-compiles this function resulting in an infinite loop. Work
+ * around that by switching optimization mode
+ */
+#pragma GCC optimize("O2")
+#endif
 
 float
 __atof_engine(uint32_t u32, int exp)
@@ -40,11 +49,11 @@ __atof_engine(uint32_t u32, int exp)
     float flt = u32;
 
     while (exp < 0) {
-        flt *= 1e-1f;
+        flt *= (float) 1e-1f;
         exp++;
     }
     while (exp > 0) {
-        flt *= 1e1f;
+        flt *= (float) 1e1f;
         exp--;
     }
     return flt;
