@@ -35,6 +35,18 @@
 
 #include "stdio_private.h"
 
+#ifdef __STDIO_BUFIO_LOCKING
+void
+__bufio_lock_init(FILE *f)
+{
+    struct __file_bufio *bf = (struct __file_bufio *) f;
+    __LIBC_LOCK();
+    if (!bf->lock)
+        __lock_init(bf->lock);
+    __LIBC_UNLOCK();
+}
+#endif
+
 int
 __bufio_flush_locked(FILE *f)
 {
@@ -147,8 +159,8 @@ bail:
 	return ret;
 }
 
-extern FILE *const stdin _ATTRIBUTE((__weak__));
-extern FILE *const stdout _ATTRIBUTE((__weak__));
+extern FILE *const stdin __weak;
+extern FILE *const stdout __weak;
 
 int
 __bufio_get(FILE *f)
@@ -216,7 +228,7 @@ __bufio_seek(FILE *f, off_t offset, int whence)
                         /* Map CUR -> SET, accounting for position within buffer */
                         whence = SEEK_SET;
                         offset += buf_pos + bf->off;
-                        __PICOLIBC_FALLTHROUGH;
+                        __fallthrough;
                 case SEEK_SET:
                         /* Optimize for seeks within buffer or just past buffer */
                         if (buf_pos <= offset && offset <= buf_pos + bf->len) {
@@ -224,7 +236,7 @@ __bufio_seek(FILE *f, off_t offset, int whence)
                                 ret = offset;
                                 break;
                         }
-                        __PICOLIBC_FALLTHROUGH;
+                        __fallthrough;
                 default:
                         ret = bufio_lseek(bf, offset, whence);
                         if (ret >= 0)
