@@ -199,8 +199,13 @@ f2d(const uint32_t ieeeMantissa, const uint32_t ieeeExponent, int max_digits, bo
 		 *
 		 * A single expression gives the right answer in both
 		 * cases, which is kinda cool
+                 *
+                 * When called from fcvt, max_decimals may be less
+                 * than zero, indicating that we want to round left of
+                 * the decimal point. In that case, make sure we generate
+                 * at least one digit
 		 */
-		max_digits = min_int(max_digits, max_int(1, max_decimals + exp + 1));
+		max_digits = min_int(max_digits, max_int(max_decimals<0, max_decimals + exp + 1));
 	}
 
 	for (;;) {
