@@ -31,7 +31,7 @@
 
 #include "stdio_private.h"
 
-#ifdef _WANT_FAST_BUFIO
+#ifdef __FAST_BUFIO
 #include "../stdlib/mul_overflow.h"
 #endif
 
@@ -41,10 +41,11 @@ fwrite(const void *ptr, size_t size, size_t nmemb, FILE *stream)
 	size_t i, j;
 	const uint8_t *cp = (const uint8_t *) ptr;
 
+        __flockfile(stream);
 	if ((stream->flags & __SWR) == 0 || size == 0)
-		return 0;
+		__funlock_return(stream, 0);
 
-#ifdef _WANT_FAST_BUFIO
+#ifdef __FAST_BUFIO
         size_t bytes;
         struct __file_bufio *bf = (struct __file_bufio *) stream;
 
@@ -90,13 +91,13 @@ fwrite(const void *ptr, size_t size, size_t nmemb, FILE *stream)
                         }
                 }
                 __bufio_unlock(stream);
-                return (cp - (uint8_t *) ptr) / size;
+                __funlock_return(stream, (cp - (uint8_t *) ptr) / size);
         }
 #endif
 	for (i = 0; i < nmemb; i++)
 		for (j = 0; j < size; j++)
 			if (stream->put(*cp++, stream) < 0)
-				return i;
+				__funlock_return(stream, i);
 
-	return i;
+	__funlock_return(stream, i);
 }
