@@ -36,17 +36,7 @@ snprintf(char *s, size_t n, const char *fmt, ...)
 {
 	va_list ap;
 	int i;
-
-	/* Restrict max output length to INT_MAX, as snprintf() return
-	   signed int. The fputc() function uses a signed comparison
-	   between estimated len and f.size field. So we can write a
-	   negative value into f.size in the case of n was 0. Note,
-	   that f.size will be a max number of nonzero symbols.	*/
-
-	if ((int) n < 0)
-		n = (unsigned)INT_MAX + 1;
-
-	struct __file_str f = FDEV_SETUP_STRING_WRITE(s, n ? n - 1 : 0);
+	struct __file_str f = FDEV_SETUP_STRING_WRITE(s, FDEV_STRING_WRITE_END(s, n));
 
 	va_start(ap, fmt);
 	i = vfprintf(&f.file, fmt, ap);
@@ -58,11 +48,4 @@ snprintf(char *s, size_t n, const char *fmt, ...)
 	return i;
 }
 
-#ifdef __LONG_DOUBLE_IEEE128__
-#if defined(_HAVE_ALIAS_ATTRIBUTE)
-#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
-#pragma GCC diagnostic ignored "-Wmissing-attributes"
-#endif
-__strong_reference(snprintf, __snprintfieee128);
-#endif
-#endif
+__ieee128_reference(snprintf, __snprintfieee128);
