@@ -33,39 +33,46 @@
 /* From: Id: printf_p_new.c,v 1.1.1.9 2002/10/15 20:10:28 joerg_wunsch Exp */
 /* $Id: vfprintf.c 2191 2010-11-05 13:45:57Z arcanum $ */
 
+#ifndef PRINTF_NAME
+# define PRINTF_VARIANT __IO_VARIANT_DOUBLE
+# define PRINTF_NAME __d_vfprintf
+#endif
+
 #include "stdio_private.h"
 #include "../../libm/common/math_config.h"
 #include "../stdlib/local.h"
 
-#ifdef WIDE_CHARS
-#define CHAR wchar_t
-#define UCHAR wchar_t
-#define vfprintf vfwprintf
-#define PRINTF_LEVEL PRINTF_DBL
-#else
-#define CHAR char
-#define UCHAR unsigned char
-#endif
-
 /*
- * This file can be compiled into more than one flavour:
+ * This file can be compiled into more than one flavour by setting
+ * PRINTF_VARIANT to:
  *
- *  PRINTF_MIN: limited integer-only support with option for long long
+ *  __IO_VARIANT_MINIMAL: limited integer-only support with option for long long
  *
- *  PRINTF_STD: full integer support with options for positional
- *              params and long long
+ *  __IO_VARIANT_INTEGER: integer support except for long long with
+ *              options for positional params
  *
- *  PRINTF_LLONG: full integer support including long long with
+ *  __IO_VARIANT_LLONG: full integer support including long long with
  *                options for positional params
  *
- *  PRINTF_FLT: full support
+ *  __IO_VARIANT_FLOAT: full integer support along with float, but not double
+ *
+ *  __IO_VARIANT_DOUBLE: full support
  */
 
-#ifndef PRINTF_LEVEL
-#  define PRINTF_LEVEL PRINTF_DBL
-#  ifndef _FORMAT_DEFAULT_DOUBLE
-#    define vfprintf __d_vfprintf
-#  endif
+# if __IO_DEFAULT != PRINTF_VARIANT || defined(WIDE_CHARS)
+#  define vfprintf PRINTF_NAME
+# endif
+
+#ifdef WIDE_CHARS
+# define CHAR wchar_t
+# if __SIZEOF_WCHAR_T__ == 2
+#  define UCHAR          uint16_t
+# elif __SIZEOF_WCHAR_T__ == 4
+#  define UCHAR          uint32_t
+# endif
+#else
+# define CHAR char
+# define UCHAR unsigned char
 #endif
 
 /*
@@ -73,51 +80,60 @@
  * values computed in stdio.h
  */
 
-#if PRINTF_LEVEL == PRINTF_MIN
+#if PRINTF_VARIANT == __IO_VARIANT_MINIMAL
+
 # define _NEED_IO_SHRINK
-# if defined(_WANT_MINIMAL_IO_LONG_LONG) && __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
+# if defined(__IO_MINIMAL_LONG_LONG) && __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
 #  define _NEED_IO_LONG_LONG
 # endif
-# ifdef _WANT_IO_C99_FORMATS
+# ifdef __IO_C99_FORMATS
 #  define _NEED_IO_C99_FORMATS
 # endif
-#elif PRINTF_LEVEL == PRINTF_STD
-# if defined(_WANT_IO_LONG_LONG) && __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
+
+#elif PRINTF_VARIANT == __IO_VARIANT_INTEGER
+
+# if defined(__IO_LONG_LONG) && __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
 #  define _NEED_IO_LONG_LONG
 # endif
-# ifdef _WANT_IO_POS_ARGS
+# ifdef __IO_POS_ARGS
 #  define _NEED_IO_POS_ARGS
 # endif
-# ifdef _WANT_IO_C99_FORMATS
+# ifdef __IO_C99_FORMATS
 #  define _NEED_IO_C99_FORMATS
 # endif
-# ifdef _WANT_IO_PERCENT_B
+# ifdef __IO_PERCENT_B
 #  define _NEED_IO_PERCENT_B
 # endif
-#elif PRINTF_LEVEL == PRINTF_LLONG
+
+#elif PRINTF_VARIANT == __IO_VARIANT_LLONG
+
 # if __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
 #  define _NEED_IO_LONG_LONG
 # endif
-# ifdef _WANT_IO_POS_ARGS
+# ifdef __IO_POS_ARGS
 #  define _NEED_IO_POS_ARGS
 # endif
-# ifdef _WANT_IO_C99_FORMATS
+# ifdef __IO_C99_FORMATS
 #  define _NEED_IO_C99_FORMATS
 # endif
-# ifdef _WANT_IO_PERCENT_B
+# ifdef __IO_PERCENT_B
 #  define _NEED_IO_PERCENT_B
 # endif
-#elif PRINTF_LEVEL == PRINTF_FLT
+
+#elif PRINTF_VARIANT == __IO_VARIANT_FLOAT
+
 # if __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
 #  define _NEED_IO_LONG_LONG
 # endif
 # define _NEED_IO_POS_ARGS
 # define _NEED_IO_C99_FORMATS
-# ifdef _WANT_IO_PERCENT_B
+# ifdef __IO_PERCENT_B
 #  define _NEED_IO_PERCENT_B
 # endif
 # define _NEED_IO_FLOAT
-#elif PRINTF_LEVEL == PRINTF_DBL
+
+#elif PRINTF_VARIANT == __IO_VARIANT_DOUBLE
+
 # if __SIZEOF_LONG_LONG__ > __SIZEOF_LONG__
 #  define _NEED_IO_LONG_LONG
 # endif
@@ -126,19 +142,22 @@
 # endif
 # define _NEED_IO_POS_ARGS
 # define _NEED_IO_C99_FORMATS
-# ifdef _WANT_IO_PERCENT_B
+# ifdef __IO_PERCENT_B
 #  define _NEED_IO_PERCENT_B
 # endif
 # define _NEED_IO_DOUBLE
-# if defined(_WANT_IO_LONG_DOUBLE) && __SIZEOF_LONG_DOUBLE__ > __SIZEOF_DOUBLE__
+# if defined(__IO_LONG_DOUBLE) && __SIZEOF_LONG_DOUBLE__ > __SIZEOF_DOUBLE__
 #  define _NEED_IO_LONG_DOUBLE
 # endif
+
 #else
-# error invalid PRINTF_LEVEL
+
+# error invalid PRINTF_VARIANT
+
 #endif
 
 /* Figure out which multi-byte char support we need */
-#if defined(_NEED_IO_WCHAR) && defined(_MB_CAPABLE)
+#if defined(_NEED_IO_WCHAR) && defined(__MB_CAPABLE)
 # ifdef WIDE_CHARS
 /* need to convert multi-byte chars to wide chars */
 #  define _NEED_IO_MBTOWIDE
@@ -147,7 +166,7 @@
 # endif
 #endif
 
-#if PRINTF_LEVEL >= PRINTF_FLT
+#if IO_VARIANT_IS_FLOAT(PRINTF_VARIANT)
 #include "dtoa.h"
 #endif
 
@@ -505,7 +524,7 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
         char __mb[MB_LEN_MAX];
 #endif
 #endif
-#if PRINTF_LEVEL >= PRINTF_FLT
+#if IO_VARIANT_IS_FLOAT(PRINTF_VARIANT)
 	struct dtoa __dtoa;
 #endif
     } u;
@@ -541,8 +560,10 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 #endif
 #endif
 
+    __flockfile(stream);
+
     if ((stream->flags & __SWR) == 0)
-	return EOF;
+	__funlock_return(stream, EOF);
 
 #ifdef _NEED_IO_POS_ARGS
     va_copy(ap, ap_orig);
@@ -566,6 +587,9 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 #ifdef _NEED_IO_POS_ARGS
         argno = 0;
 #endif
+#ifdef _NEED_IO_WCHAR
+        wchar_t *wstr = NULL;
+#endif
 
 	do {
 	    if (flags < FL_WIDTH) {
@@ -575,7 +599,7 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 		    continue;
 		  case '+':
 		    flags |= FL_PLUS;
-		    __PICOLIBC_FALLTHROUGH;
+		    __fallthrough;
 		  case ' ':
 		    flags |= FL_SPACE;
 		    continue;
@@ -704,7 +728,7 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 #endif
             )
         {
-#if PRINTF_LEVEL >= PRINTF_FLT
+#if IO_VARIANT_IS_FLOAT(PRINTF_VARIANT)
             uint8_t sign;		/* sign character (or 0)	*/
             uint8_t ndigs;		/* number of digits to convert */
             unsigned char case_convert; /* subtract to correct case */
@@ -1050,7 +1074,7 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
                     my_putc ('0' + exp, stream);
                 }
 	    }
-#else		/* to: PRINTF_LEVEL >= PRINTF_FLT */
+#else		/* to: IO_VARIANT_IS_FLOAT(PRINTF_VARIANT) */
             SKIP_FLOAT_ARG(flags, ap);
 	    pnt = "*float*";
 	    size = sizeof ("*float*") - 1;
@@ -1061,7 +1085,6 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
         {
             int buf_len;
 #ifdef _NEED_IO_WCHAR
-            wchar_t *wstr = NULL;
             pnt = NULL;
 #endif
 
@@ -1162,7 +1185,7 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 #endif
                 }
 #endif
-#if defined(_PRINTF_PERCENT_N) || defined(VFPRINTF_S)
+#if defined(__IO_PERCENT_N) || defined(VFPRINTF_S)
             } else if (c == 'n') {
 #ifdef VFPRINTF_S
                 msg = "format string contains percent-n";
@@ -1190,7 +1213,8 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
                     arg_to_signed(ap, flags, x_s);
 
                     if (x_s < 0) {
-                        x_s = -x_s;
+                        /* Use unsigned in case x_s is the largest negative value */
+                        x_s = (ultoa_signed_t) -(ultoa_unsigned_t) x_s;
                         flags |= FL_NEGATIVE;
                     }
 
@@ -1342,7 +1366,7 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 #ifdef _NEED_IO_POS_ARGS
     va_end(ap);
 #endif
-    return stream_len;
+    __funlock_return(stream, stream_len);
 #undef my_putc
 #undef ap
   fail:
@@ -1361,12 +1385,13 @@ int vfprintf (FILE * stream, const CHAR *fmt, va_list ap_orig)
 #endif
 }
 
-#ifndef VFPRINTF_S
-#if defined(_FORMAT_DEFAULT_DOUBLE) && !defined(vfprintf)
-#ifdef _HAVE_ALIAS_ATTRIBUTE
-__strong_reference(vfprintf, __d_vfprintf);
-#else
-int __d_vfprintf (FILE * stream, const char *fmt, va_list ap) { return vfprintf(stream, fmt, ap); }
-#endif
-#endif
+#if !defined(VFPRINTF_S) && !defined(WIDE_CHARS)
+# if PRINTF_VARIANT == __IO_DEFAULT
+#  undef vfprintf
+#  ifdef __strong_reference
+__strong_reference(vfprintf, PRINTF_NAME);
+#  else
+int PRINTF_NAME (FILE * stream, const char *fmt, va_list ap) { return vfprintf(stream, fmt, ap); }
+#  endif
+# endif
 #endif
