@@ -38,7 +38,7 @@
 /* Correct special case results in non-nearest rounding modes.  */
 # define WANT_ROUNDING 1
 #endif
-#ifdef _IEEE_LIBM
+#ifdef __IEEE_LIBM
 # define WANT_ERRNO 0
 # define _LIB_VERSION _IEEE_
 #else
@@ -54,13 +54,8 @@
 #define _IEEE_  -1
 #define _POSIX_ 0
 
-#ifdef _HAVE_BUILTIN_EXPECT
-# define likely(x) __builtin_expect (!!(x), 1)
+# define likely(x) __builtin_expect (x, 1)
 # define unlikely(x) __builtin_expect (x, 0)
-#else
-# define likely(x) (x)
-# define unlikely(x) (x)
-#endif
 
 /* Compiler can inline round as a single instruction.  */
 #ifndef HAVE_FAST_ROUND
@@ -283,7 +278,7 @@ issignaling64_inline (__float64 x)
 #define CONST_FORCE_FLOAT_MODIFIER
 #endif
 
-#ifdef PICOLIBC_FLOAT_NOEXCEPT
+#ifdef __FLOAT_NOEXCEPT
 #define FORCE_FLOAT     float
 #define CONST_FORCE_FLOAT const float
 #define pick_float_except(expr,val)    (val)
@@ -293,7 +288,7 @@ issignaling64_inline (__float64 x)
 #define pick_float_except(expr,val)    (expr)
 #endif
 
-#ifdef PICOLIBC_DOUBLE_NOEXCEPT
+#ifdef __DOUBLE_NOEXCEPT
 #define FORCE_DOUBLE    double
 #define CONST_FORCE_DOUBLE      const double
 #define pick_double_except(expr,val)    (val)
@@ -303,7 +298,7 @@ issignaling64_inline (__float64 x)
 #define pick_double_except(expr,val)    (expr)
 #endif
 
-#ifdef PICOLIBC_LONG_DOUBLE_NOEXCEPT
+#ifdef __LONG_DOUBLE_NOEXCEPT
 #define FORCE_LONG_DOUBLE       long double
 #define CONST_FORCE_LONG_DOUBLE const long double
 #define pick_long_double_except(expr,val)       (val)
@@ -341,7 +336,7 @@ force_eval_double (double x)
   (void) y;
 }
 
-#ifdef _HAVE_LONG_DOUBLE
+#ifdef __HAVE_LONG_DOUBLE
 static __always_inline long double
 opt_barrier_long_double (long double x)
 {
@@ -455,25 +450,25 @@ force_eval_long_double (long double x)
 #endif
 
 #ifdef _DOUBLE_IS_32BITS
-# ifdef _HAVE_ALIAS_ATTRIBUTE
-#  define _MATH_ALIAS_d_to_f(name) extern double _D_NAME(name)(void) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_d_to_f(name) extern double _D_NAME(name)(double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_D_to_f(name) extern double _D_NAME(name)(const double *x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_s_to_f(name) extern double _D_NAME(name)(const char *x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_dd_to_f(name) extern double _D_NAME(name)(double x, double y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_dl_to_f(name) extern double _D_NAME(name)(double x, long double y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_dD_to_f(name) extern double _D_NAME(name)(double x, double *y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_ddd_to_f(name) extern double _D_NAME(name)(double x, double y, double z) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_dI_to_f(name) extern double _D_NAME(name)(double x, int *y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_ddI_to_f(name) extern double _D_NAME(name)(double x, double y, int *z) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_id_to_f(name) extern double _D_NAME(name)(int n, double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_di_to_f(name) extern double _D_NAME(name)(double x, int n) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_d_dj_to_f(name) extern double _D_NAME(name)(double x, long n) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_i_d_to_f(name) extern int _D_NAME(name)(double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_j_d_to_f(name) extern long _D_NAME(name)(double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_k_d_to_f(name) extern long long _D_NAME(name)(double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_i_dd_to_f(name) extern int _D_NAME(name)(double x, double y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#  define _MATH_ALIAS_v_dDD_to_f(name) extern void _D_NAME(name)(double x, double *y, double *z) __attribute__((__alias__(_FLOAT_ALIAS(name))));
+# ifdef __strong_reference
+#  define _MATH_ALIAS_d_to_f(name) __strong_reference_dup(_FLOAT_NAME(name), _D_NAME(name));
+#  define _MATH_ALIAS_d_d_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_D_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_s_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_dd_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_dl_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_dD_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_ddd_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_dI_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_ddI_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_id_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_di_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_d_dj_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_i_d_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_j_d_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_k_d_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_i_dd_to_f(name) _MATH_ALIAS_d_to_f(name)
+#  define _MATH_ALIAS_v_dDD_to_f(name) _MATH_ALIAS_d_to_f(name)
 # else
 #  define _MATH_ALIAS_d_to_f(name) double _D_NAME(name)(void) { return (double) __FLOAT_NAME(name)(); }
 #  define _MATH_ALIAS_d_d_to_f(name) double _D_NAME(name)(double x) { return (double) __FLOAT_NAME(name)((float) x); }
@@ -513,34 +508,34 @@ force_eval_long_double (long double x)
 # define _MATH_ALIAS_k_d_to_f(name)
 # define _MATH_ALIAS_i_dd_to_f(name)
 # define _MATH_ALIAS_v_dDD_to_f(name)
-# ifdef PICOLIBC_DOUBLE_NOEXCEPT
-#  define PICOLIBC_FLOAT64_NOEXCEPT
+# ifdef __DOUBLE_NOEXCEPT
+#  define __FLOAT64_NOEXCEPT
 # endif
-# ifdef PICOLIBC_DOUBLE_NOROUND
-#  define PICOLIBC_FLOAT64_NOROUND
+# ifdef __DOUBLE_NOROUND
+#  define __FLOAT64_NOROUND
 # endif
 #endif
 
 #ifdef _LDBL_EQ_DBL
 # ifdef _DOUBLE_IS_32BITS
-#  ifdef _HAVE_ALIAS_ATTRIBUTE
-#   define _MATH_ALIAS_l_to_f(name) extern long double _LD_NAME(name)(void) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_l_to_f(name) extern long double _LD_NAME(name)(long double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_L_to_f(name) extern long double _LD_NAME(name)(const long double *x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_s_to_f(name) extern long double _LD_NAME(name)(const char *x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_ll_to_f(name) extern long double _LD_NAME(name)(long double x, long double y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_lL_to_f(name) extern long double _LD_NAME(name)(long double x, long double *y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_lll_to_f(name) extern long double _LD_NAME(name)(long double x, long double y, long double z) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_lI_to_f(name) extern long double _LD_NAME(name)(long double x, int *y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_llI_to_f(name) extern long double _LD_NAME(name)(long double x, long double y, int *z) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_il_to_f(name) extern long double _LD_NAME(name)(int n, long double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_li_to_f(name) extern long double _LD_NAME(name)(long double x, int n) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_l_lj_to_f(name) extern long double _LD_NAME(name)(long double x, long n) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_i_l_to_f(name) extern int _LD_NAME(name)(long double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_j_l_to_f(name) extern long _LD_NAME(name)(long double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_k_l_to_f(name) extern long long _LD_NAME(name)(long double x) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_i_ll_to_f(name) extern int _LD_NAME(name)(long double x, long double y) __attribute__((__alias__(_FLOAT_ALIAS(name))));
-#   define _MATH_ALIAS_v_lLL_to_f(name) extern void _LD_NAME(name)(long double x, long double *y, long double *z) __attribute__((__alias__(_FLOAT_ALIAS(name))));
+#  ifdef __strong_reference
+#   define _MATH_ALIAS_l_to_f(name) __strong_reference_dup(_FLOAT_NAME(name), _LD_NAME(name));
+#   define _MATH_ALIAS_l_l_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_L_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_s_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_ll_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_lL_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_lll_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_lI_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_llI_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_il_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_li_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_l_lj_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_i_l_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_j_l_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_k_l_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_i_ll_to_f(name) _MATH_ALIAS_l_to_f(name)
+#   define _MATH_ALIAS_v_lLL_to_f(name) _MATH_ALIAS_l_to_f(name)
 #  else
 #   define _MATH_ALIAS_l_to_f(name) long double _LD_NAME(name)(void) { return (long double) _FLOAT_NAME(name)(); }
 #   define _MATH_ALIAS_l_l_to_f(name) long double _LD_NAME(name)(long double x) { return (long double) _FLOAT_NAME(name)((float) x); }
@@ -594,24 +589,24 @@ force_eval_long_double (long double x)
 #  define _MATH_ALIAS_k_l_to_f(name)
 #  define _MATH_ALIAS_i_ll_to_f(name)
 #  define _MATH_ALIAS_v_lLL_to_f(name)
-#  ifdef _HAVE_ALIAS_ATTRIBUTE
-#   define _MATH_ALIAS_l_to_d(name) extern long double _LD_NAME(name)(void) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_l_to_d(name) extern long double _LD_NAME(name)(long double x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_L_to_d(name) extern long double _LD_NAME(name)(const long double *x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_s_to_d(name) extern long double _LD_NAME(name)(const char *x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_ll_to_d(name) extern long double _LD_NAME(name)(long double x, long double y) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_lL_to_d(name) extern long double _LD_NAME(name)(long double x, long double *y) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_lll_to_d(name) extern long double _LD_NAME(name)(long double x, long double y, long double z) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_lI_to_d(name) extern long double _LD_NAME(name)(long double x, int *y) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_llI_to_d(name) extern long double _LD_NAME(name)(long double x, long double y, int *z) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_il_to_d(name) extern long double _LD_NAME(name)(int n, long double x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_li_to_d(name) extern long double _LD_NAME(name)(long double x, int n) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_l_lj_to_d(name) extern long double _LD_NAME(name)(long double x, long n) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_i_l_to_d(name) extern int _LD_NAME(name)(long double x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_j_l_to_d(name) extern long _LD_NAME(name)(long double x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_k_l_to_d(name) extern long long _LD_NAME(name)(long double x) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_i_ll_to_d(name) extern int _LD_NAME(name)(long double x, long double y) __attribute__((__alias__(_D_ALIAS(name))));
-#   define _MATH_ALIAS_v_lLL_to_d(name) extern void _LD_NAME(name)(long double x, long double *y, long double *z) __attribute__((__alias__(_D_ALIAS(name))));
+#  ifdef __strong_reference
+#   define _MATH_ALIAS_l_to_d(name) __strong_reference_dup(_D_NAME(name), _LD_NAME(name));
+#   define _MATH_ALIAS_l_l_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_L_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_s_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_ll_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_lL_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_lll_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_lI_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_llI_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_il_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_li_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_l_lj_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_i_l_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_j_l_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_k_l_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_i_ll_to_d(name) _MATH_ALIAS_l_to_d(name)
+#   define _MATH_ALIAS_v_lLL_to_d(name) _MATH_ALIAS_l_to_d(name)
 #  else
 #   define _MATH_ALIAS_l_to_d(name) long double _LD_NAME(name)(void) { return (long double) _D_NAME(name)(); }
 #   define _MATH_ALIAS_l_l_to_d(name) long double _LD_NAME(name)(long double x) { return (long double) _D_NAME(name)((double) x); }
@@ -640,11 +635,11 @@ force_eval_long_double (long double x)
 #  define CONST_FORCE_FLOAT64 CONST_FORCE_LONG_DOUBLE
 #  define pick_float64_except(a,b) pick_long_double_except(a,b)
 #  define _NEED_FLOAT64
-#  ifdef PICOLIBC_LONG_DOUBLE_NOEXCEPT
-#   define PICOLIBC_FLOAT64_NOEXCEPT
+#  ifdef __LONG_DOUBLE_NOEXCEPT
+#   define __FLOAT64_NOEXCEPT
 #  endif
-#  ifdef PICOLIBC_LONG_DOUBLE_NOROUND
-#   define PICOLIBC_FLOAT64_NOROUND
+#  ifdef __LONG_DOUBLE_NOROUND
+#   define __FLOAT64_NOROUND
 #  endif
 #  define __F_64(x)     x ## L
 #  define _F_64(x)      __F_64(x)
@@ -896,7 +891,7 @@ HIDDEN float __math_divzerof (uint32_t);
 /* Invalid input unless it is a quiet NaN.  */
 HIDDEN float __math_invalidf (float);
 /* set invalid exception */
-#if defined(FE_INVALID) && !defined(PICOLIBC_FLOAT_NOEXECPT)
+#if defined(FE_INVALID) && !defined(__FLOAT_NOEXCEPT)
 HIDDEN void __math_set_invalidf(void);
 #else
 #define __math_set_invalidf()   ((void) 0)
@@ -920,7 +915,7 @@ check_uflowf (float x)
   return WANT_ERRNO ? __math_check_uflowf (x) : x;
 }
 
-#if defined(FE_INEXACT) && !defined(PICOLIBC_FLOAT_NOEXECPT)
+#if defined(FE_INEXACT) && !defined(__FLOAT_NOEXCEPT)
 float __math_inexactf(float val);
 void __math_set_inexactf(void);
 #else
@@ -936,7 +931,7 @@ __math_with_errnof (float y, int e);
 #endif
 
 /* Check if the result is a denorm. */
-#if (defined(FE_UNDERFLOW) && !defined(PICOLIBC_FLOAT_NOEXCEPT)) || WANT_ERRNO
+#if (defined(FE_UNDERFLOW) && !defined(__FLOAT_NOEXCEPT)) || WANT_ERRNO
 float __math_denormf (float x);
 #else
 #define __math_denormf(x) (x)
@@ -957,7 +952,7 @@ HIDDEN __float64 __math_divzero (uint32_t);
 /* Invalid input unless it is a quiet NaN.  */
 HIDDEN __float64 __math_invalid (__float64);
 /* set invalid exception */
-#if defined(FE_INVALID) && !defined(PICOLIBC_DOUBLE_NOEXECPT)
+#if defined(FE_INVALID) && !defined(__DOUBLE_NOEXCEPT)
 HIDDEN void __math_set_invalid(void);
 #else
 #define __math_set_invalid()    ((void) 0)
@@ -982,7 +977,7 @@ check_uflow (__float64 x)
 }
 
 /* Set inexact exception */
-#if defined(FE_INEXACT) && !defined(PICOLIBC_FLOAT64_NOEXECPT)
+#if defined(FE_INEXACT) && !defined(__FLOAT64_NOEXCEPT)
 __float64 __math_inexact64(__float64 x);
 void __math_set_inexact64(void);
 #else
@@ -997,7 +992,7 @@ __math_with_errno (__float64 y, int e);
 #define __math_with_errno(x, e) (x)
 #endif
 
-#if (defined(FE_UNDERFLOW) && !defined(PICOLIBC_FLOAT64_NOEXCEPT)) || WANT_ERRNO
+#if (defined(FE_UNDERFLOW) && !defined(__FLOAT64_NOEXCEPT)) || WANT_ERRNO
 __float64 __math_denorm (__float64 x);
 #else
 #define __math_denorm(x) (x)
@@ -1005,7 +1000,7 @@ __float64 __math_denorm (__float64 x);
 
 #endif /* _NEED_FLOAT64 */
 
-#ifdef _HAVE_LONG_DOUBLE
+#ifdef __HAVE_LONG_DOUBLE
 HIDDEN long double __math_oflowl (uint32_t);
 /* The result underflows to 0 in nearest rounding mode.  */
 HIDDEN long double __math_uflowl (uint32_t);
@@ -1016,7 +1011,7 @@ HIDDEN long double __math_divzerol (uint32_t);
 /* Invalid input unless it is a quiet NaN.  */
 HIDDEN long double __math_invalidl (long double);
 /* set invalid exception */
-#if defined(FE_INVALID) && !defined(PICOLIBC_LONG_DOUBLE_NOEXECPT)
+#if defined(FE_INVALID) && !defined(__LONG_DOUBLE_NOEXCEPT)
 HIDDEN void __math_set_invalidl(void);
 #else
 #define __math_set_invalidl()    ((void) 0)
@@ -1040,7 +1035,7 @@ check_uflowl (long double x)
   return WANT_ERRNO ? __math_check_uflowl (x) : x;
 }
 
-#if defined(FE_INEXACT) && !defined(PICOLIBC_LONG_DOUBLE_NOEXECPT)
+#if defined(FE_INEXACT) && !defined(__LONG_DOUBLE_NOEXCEPT)
 long double __math_inexactl(long double val);
 void __math_set_inexactl(void);
 #else
@@ -1055,13 +1050,13 @@ __math_with_errnol (long double y, int e);
 #define __math_with_errnol(x, e) (x)
 #endif
 
-#if (defined(FE_UNDERFLOW) && !defined(PICOLIBC_LONG_DOUBLE_NOEXCEPT)) || WANT_ERRNO
+#if (defined(FE_UNDERFLOW) && !defined(__LONG_DOUBLE_NOEXCEPT)) || WANT_ERRNO
 long double __math_denorml(long double x);
 #else
 #define __math_denorml(x) (x)
 #endif
 
-#endif /* _HAVE_LONG_DOUBLE */
+#endif /* __HAVE_LONG_DOUBLE */
 
 /* Shared between expf, exp2f and powf.  */
 #define EXP2F_TABLE_BITS 5
@@ -1148,7 +1143,7 @@ extern const struct log_data
   double poly[LOG_POLY_ORDER - 1]; /* First coefficient is 1.  */
   double poly1[LOG_POLY1_ORDER - 1];
   struct {double invc, logc;} tab[1 << LOG_TABLE_BITS];
-#if !_HAVE_FAST_FMA
+#if !__HAVE_FAST_FMA
   struct {double chi, clo;} tab2[1 << LOG_TABLE_BITS];
 #endif
 } __log_data HIDDEN;
@@ -1163,7 +1158,7 @@ extern const struct log2_data
   double poly[LOG2_POLY_ORDER - 1];
   double poly1[LOG2_POLY1_ORDER - 1];
   struct {double invc, logc;} tab[1 << LOG2_TABLE_BITS];
-#if !_HAVE_FAST_FMA
+#if !__HAVE_FAST_FMA
   struct {double chi, clo;} tab2[1 << LOG2_TABLE_BITS];
 #endif
 } __log2_data HIDDEN;
@@ -1283,7 +1278,7 @@ extern int __signgam;
 #define tgamma64 _NAME_64(tgamma)
 #define trunc64 _NAME_64(trunc)
 
-#ifdef _HAVE_ALIAS_ATTRIBUTE
+#ifdef __strong_reference
 float _powf(float, float);
 float _sinf(float);
 float _cosf(float);
@@ -1294,7 +1289,7 @@ __float64 _sin64(__float64);
 __float64 _cos64(__float64);
 #endif
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 long double _powl(long double, long double);
 long double _sinl(long double);
 long double _cosl(long double);
@@ -1313,12 +1308,12 @@ long double _cosl(long double);
 #define _sin64(x) sin64(x)
 #define _cos64(x) cos64(x)
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 #define _powl(x,y) powl(x,y)
 #define _sinl(x) sinl(x)
 #define _cosl(x) cosl(x)
-#endif /* _HAVE_LONG_DOUBLE_MATH */
+#endif /* __HAVE_LONG_DOUBLE_MATH */
 
-#endif /* _HAVE_ALIAS_ATTRIBUTE */
+#endif /* __strong_reference */
 
 #endif
