@@ -28,7 +28,9 @@
 
 #include "math_config.h"
 
-static const FORCE_FLOAT64 VAL = pick_float64_except(_F_64(0.0), (__float64) NAN);
+#ifdef _NEED_FLOAT64
+
+static CONST_FORCE_FLOAT64 VAL = pick_float64_except(_F_64(0.0), (__float64) NAN);
 
 HIDDEN __float64
 __math_invalid (__float64 x)
@@ -46,3 +48,5 @@ __math_set_invalid(void)
     force_eval_float64(pick_float64_except(VAL / VAL, VAL));
 }
 #endif
+
+#endif
