@@ -31,16 +31,14 @@
 
 #if WANT_ERRNO_UFLOW
 
-static const FORCE_FLOAT VAL = pick_float_except(0x1.4p-75f, 0.0f);
+static CONST_FORCE_FLOAT VAL = pick_float_except(0x1.4p-75f, 0.0f);
 
 /* Underflows to zero in some non-nearest rounding mode, setting errno
    is valid even if the result is non-zero, but in the subnormal range.  */
 HIDDEN float
 __math_may_uflowf (uint32_t sign)
 {
-    float y = pick_float_except(VAL * VAL, VAL);
-    if (sign)
-        y = -y;
+    float y = pick_float_except((sign ? -VAL : VAL) * VAL, sign ? -VAL : VAL);
     return __math_with_errnof (y, ERANGE);
 }
 
