@@ -44,11 +44,11 @@ ANSI C, POSIX.
 
 #include "fdlibm.h"
 
-#if !_HAVE_FAST_FMA
+#if !__HAVE_FAST_FMA
 
 #ifdef _NEED_FLOAT64
 
-#if __FLT_EVAL_METHOD__ == 2 && defined(_HAVE_LONG_DOUBLE)
+#if __FLT_EVAL_METHOD__ == 2 && defined(__HAVE_LONG_DOUBLE)
 
 __float64
 fma64(__float64 x, __float64 y, __float64 z)
@@ -85,7 +85,7 @@ EXPONENT(FLOAT_T x)
     return _exponent64(asuint64(x));
 }
 
-#ifdef PICOLIBC_FLOAT64_NOEXCEPT
+#ifdef __FLOAT64_NOEXCEPT
 #define feraiseexcept(x) ((void) (x))
 #endif
 
@@ -97,4 +97,4 @@ _MATH_ALIAS_d_ddd(fma)
 
 #endif /* _NEED_FLOAT64 */
 
-#endif /* !_HAVE_FAST_FMA */
+#endif /* !__HAVE_FAST_FMA */
