@@ -16,16 +16,20 @@ is preserved.
  * chooses to use it instead of the C99 macro.
  */
 
+#define _ADD_D_TO_DOUBLE_FUNCS
+#define isinfd isinf
+
 #include "fdlibm.h"
 
 #ifdef _NEED_FLOAT64
 
 #undef isinf
+#undef isinfl
 
 int
 isinf64(__float64 x)
 {
-	__int32_t hx,lx;
+	__uint32_t hx,lx;
 	EXTRACT_WORDS(hx,lx,x);
 	hx &= 0x7fffffff;
 	hx |= (__uint32_t)(lx|(-lx))>>31;
@@ -33,6 +37,17 @@ isinf64(__float64 x)
 	return 1 - (int)((__uint32_t)(hx|(-hx))>>31);
 }
 
+#ifdef __strong_reference
+__strong_reference(isinf64, __isinf64);
+#else
+int
+__isinf64(float x)
+{
+    return isinf64(x);
+}
+#endif
+
 _MATH_ALIAS_i_d(isinf)
+_MATH_ALIAS_i_d(__isinf)
 
 #endif /* _NEED_FLOAT64 */
