@@ -6,7 +6,7 @@
  *
  * Developed at SunPro, a Sun Microsystems, Inc. business.
  * Permission to use, copy, modify, and distribute this
- * software is freely granted, provided that this notice 
+ * software is freely granted, provided that this notice
  * is preserved.
  * ====================================================
  */
@@ -133,7 +133,7 @@ o-
 	<<isnan>> returns 1 if the argument is a nan. <<isinf>>
 	returns 1 if the argument is infinity.  <<finite>> returns 1 if the
 	argument is zero, subnormal or normal.
-	
+
 	The <<isnanf>>, <<isinff>> and <<finitef>> functions perform the same
 	operations as their <<isnan>>, <<isinf>> and <<finite>>
 	counterparts, but on single-precision floating-point numbers.
@@ -185,23 +185,38 @@ QUICKREF
  * <math.h> for compatibility.
  */
 
+#define _ADD_D_TO_DOUBLE_FUNCS
+#define isnand isnan
+
 #include "fdlibm.h"
 
 #ifdef _NEED_FLOAT64
 
 #undef isnan
+#undef isnanl
 
 int
 isnan64(__float64 x)
 {
-	__int32_t hx,lx;
+	__uint32_t hx,lx;
 	EXTRACT_WORDS(hx,lx,x);
 	hx &= 0x7fffffff;
-	hx |= (__uint32_t)(lx|(-lx))>>31;	
+	hx |= (lx|(-lx))>>31;
 	hx = 0x7ff00000 - hx;
-	return (int)(((__uint32_t)(hx))>>31);
+	return (int)(hx>>31);
 }
 
+#ifdef __strong_reference
+__strong_reference(isnan64, __isnan64);
+#else
+int
+__isnan64(float x)
+{
+    return isnan64(x);
+}
+#endif
+
 _MATH_ALIAS_i_d(isnan)
+_MATH_ALIAS_i_d(__isnan)
 
 #endif /* _NEED_FLOAT64 */
