@@ -21,12 +21,8 @@
 
 #include "fdlibm.h"
 
-#ifdef __STDC__
-	float copysignf(float x, float y)
-#else
-	float copysignf(x,y)
-	float x,y;
-#endif
+float
+copysignf(float x, float y)
 {
 	__uint32_t ix,iy;
 	GET_FLOAT_WORD(ix,x);
