@@ -16,6 +16,7 @@ is preserved.
  */
 
 #define _ADD_D_TO_DOUBLE_FUNCS
+#define isinfd isinf
 
 #include "fdlibm.h"
 
@@ -30,10 +31,15 @@ isinff (float x)
 	return FLT_UWORD_IS_INFINITE(ix);
 }
 
-#undef isinf
+#ifdef __strong_reference
+__strong_reference(isinff, __isinff);
+#else
+int
+__isinff(float x)
+{
+    return isinff(x);
+}
+#endif
 
 _MATH_ALIAS_i_f(isinf)
-#ifdef _DOUBLE_IS_32BITS
-#define isinfd __isinfd
-_MATH_ALIAS_i_d_to_f(isinf)
-#endif
+_MATH_ALIAS_i_f(__isinf)
