@@ -17,6 +17,7 @@ is preserved.
 {
 	float x;
 
+        (void) unused;
 #if __GNUC_PREREQ (3, 3)
 	x = __builtin_nanf("");
 #else
@@ -25,12 +26,4 @@ is preserved.
 	return x;
 }
 
-#ifdef _DOUBLE_IS_32BITS
-
-	double nan(const char *arg)
-{
-	return (double) nanf(arg);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
-
+_MATH_ALIAS_f_s(nan)
