@@ -35,7 +35,7 @@
 
 #include "math_config.h"
 
-#if defined(_NEED_FLOAT_HUGE) && defined(_HAVE_BUILTIN_ISSIGNALINGL)
+#if defined(_NEED_FLOAT_HUGE) && __HAVE_BUILTIN_ISSIGNALINGL
 int
 __issignalingl (long double x)
 {
