@@ -32,7 +32,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <complex.h>
 #include <math.h>
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 
 long double
 cargl(long double complex z)
