@@ -31,7 +31,7 @@
 
 #include <complex.h>
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 
 long double complex
 catanhl(long double complex z)
