@@ -33,7 +33,7 @@
 #include <math.h>
 #include "cephes_subrl.h"
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 
 #ifdef __weak_alias
 __weak_alias(catanl, _catanl)
