@@ -30,7 +30,7 @@ PORTABILITY
 
 */
 
-#define _DEFAULT_SOURCE
+#define _GNU_SOURCE
 #include <complex.h>
 #include <math.h>
 
