@@ -34,7 +34,7 @@ PORTABILITY
 #include <complex.h>
 #include <math.h>
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 
 long double complex
 clog10l(long double complex z)
