@@ -32,7 +32,7 @@
 #include <complex.h>
 #include <math.h>
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 
 long double complex
 csinhl(long double complex z)
