@@ -34,7 +34,7 @@
 #include <math.h>
 #include "cephes_subrl.h"
 
-#ifdef _HAVE_LONG_DOUBLE_MATH
+#ifdef __HAVE_LONG_DOUBLE_MATH
 
 long double complex
 ctanl(long double complex z)
