@@ -17,7 +17,7 @@ lgammal(long double x)
 	return (lgammal_r(x, &__signgam));
 }
 
-#  ifdef _HAVE_ALIAS_ATTRIBUTE
+#  ifdef __strong_reference
 #ifdef __GNUCLIKE_PRAGMA_DIAGNOSTIC
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wunknown-warning-option"
