@@ -65,7 +65,7 @@ Peak error =  1.83e-20
 Relative error spread =  8.4e-23
 */
 
-static long double P[8] = {
+static const long double P[8] = {
  4.212760487471622013093E-5L,
  4.542931960608009155600E-4L,
  4.092666828394035500949E-3L,
@@ -75,7 +75,7 @@ static long double P[8] = {
  8.378004301573126728826E-1L,
  1.000000000000000000009E0L,
 };
-static long double Q[9] = {
+static const long double Q[9] = {
 -1.397148517476170440917E-5L,
  2.346584059160635244282E-4L,
 -1.237799246653152231188E-3L,
@@ -88,7 +88,7 @@ static long double Q[9] = {
 };
 
 /*
-static long double P[] = {
+static const long double P[] = {
 -3.01525602666895735709e0L,
 -3.25157411956062339893e1L,
 -2.92929976820724030353e2L,
@@ -98,7 +98,7 @@ static long double P[] = {
 -5.99650230220855581642e4L,
 -7.15743521530849602425e4L
 };
-static long double Q[] = {
+static const long double Q[] = {
  1.00000000000000000000e0L,
 -1.67955233807178858919e1L,
  8.85946791747759881659e1L,
@@ -123,7 +123,7 @@ Peak error =  9.44e-21
 Relative error spread =  8.8e-4
 */
 
-static long double STIR[9] = {
+static const long double STIR[9] = {
  7.147391378143610789273E-4L,
 -2.363848809501759061727E-5L,
 -5.950237554056330156018E-4L,
@@ -144,7 +144,7 @@ static const long double SQTPI = 2.50662827463100050242E0L;
  * Peak relative error 4.2e-23
  */
 
-static long double S[9] = {
+static const long double S[9] = {
 -1.193945051381510095614E-3L,
  7.220599478036909672331E-3L,
 -9.622023360406271645744E-3L,
@@ -163,7 +163,7 @@ static long double S[9] = {
  * Relative error spread =  2.5e-24
  */
 
-static long double SN[9] = {
+static const long double SN[9] = {
  1.133374167243894382010E-3L,
  7.220837261893170325704E-3L,
  9.621911155035976733706E-3L,
@@ -301,7 +301,7 @@ if( x == 0.0L )
 else
 	{
         q = check_oflowl(1.0L/x);
-        if (!isinfl(q))
+        if (!isinf(q))
                 {
                 if( x < 0.0L )
                         {
