@@ -36,11 +36,11 @@
 #include "fdlibm.h"
 #include <math.h>
 
-#if defined(_HAVE_LONG_DOUBLE_MATH) && defined(_NEED_FLOAT_HUGE)
-#define _HAVE_LD_SUPPORT
+#if defined(__HAVE_LONG_DOUBLE_MATH) && defined(_NEED_FLOAT_HUGE)
+#define __HAVE_LD_SUPPORT
 #endif
 
-#ifdef _HAVE_LD_SUPPORT
+#ifdef __HAVE_LD_SUPPORT
 
 typedef uint32_t u_int32_t;
 typedef uint64_t u_int64_t;
