@@ -24,6 +24,7 @@
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */
 
+#if __ARM_FP & 0x8
 #include <math.h>
 
 double
@@ -40,3 +41,7 @@ nearbyint (double x)
 #endif
     return x;
 }
+
+#else
+#include "../../math/s_nearbyint.c"
+#endif
