@@ -33,18 +33,20 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 64
 
-double
-copysign (double x, double y)
+__float64
+copysign64 (__float64 x, __float64 y)
 {
-  double result;
+  __float64 result;
   __asm__("fsgnj.d\t%0, %1, %2" : "=f"(result) : "f"(x), "f"(y));
   return result;
 }
 
+_MATH_ALIAS_d_dd(copysign)
+
 #else
 #include "../../common/s_copysign.c"
 #endif
