@@ -33,18 +33,20 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 64
 
-double
-fabs (double x)
+__float64
+fabs64(__float64 x)
 {
-  double result;
+  __float64 result;
   __asm__("fabs.d\t%0, %1" : "=f"(result) : "f"(x));
   return result;
 }
 
+_MATH_ALIAS_d_d(fabs)
+
 #else
 #include "../../math/s_fabs.c"
 #endif
