@@ -33,19 +33,20 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
-#include "math_config.h"
+#include "fdlibm.h"
 
-#if _HAVE_FAST_FMA
+#if __HAVE_FAST_FMA
 
-double
-fma (double x, double y, double z)
+__float64
+fma64(__float64 x, __float64 y, __float64 z)
 {
-	double result;
+	__float64 result;
 	__asm__("fmadd.d %0, %1, %2, %3" : "=f" (result) : "f" (x), "f" (y), "f" (z));
 	return result;
 }
 
+_MATH_ALIAS_d_ddd(fma)
+
 #else
 #include "../../common/s_fma.c"
 #endif
