@@ -33,14 +33,14 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 64
 
-double
-fmin (double x, double y)
+__float64
+fmin (__float64 x, __float64 y)
 {
-    double result;
+    __float64 result;
     if (issignaling(x) || issignaling(y))
         return x + y;
 
@@ -48,6 +48,8 @@ fmin (double x, double y)
     return result;
 }
 
+_MATH_ALIAS_d_dd(fmin)
+
 #else
 #include "../../common/s_fmin.c"
 #endif
