@@ -33,11 +33,12 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 64
+
 long int
-lround (double x)
+lround64 (__float64 x)
 {
   long result;
   __asm__(
@@ -51,6 +52,9 @@ lround (double x)
        "\t%0, %1, rmm" : "=r"(result) : "f"(x));
   return result;
 }
+
+_MATH_ALIAS_j_d(lround)
+
 #else
 #include "../../common/s_lround.c"
 #endif
