@@ -33,7 +33,7 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 32
 
@@ -45,6 +45,8 @@ copysignf (float x, float y)
   return result;
 }
 
+_MATH_ALIAS_f_ff(copysign)
+
 #else
 #include "../../common/sf_copysign.c"
 #endif
