@@ -33,8 +33,7 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#define _DEFAULT_SOURCE
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 32
 
@@ -44,10 +43,7 @@ int finitef(float x)
 	return (fclass & (FCLASS_INF | FCLASS_NAN)) == 0;
 }
 
-#if defined(_HAVE_ALIAS_ATTRIBUTE)
-#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
-#pragma GCC diagnostic ignored "-Wmissing-attributes"
-#endif
+#ifdef __strong_reference
 __strong_reference(finitef, __finitef);
 #else
 
@@ -58,6 +54,9 @@ __finitef(float x)
 }
 #endif
 
+_MATH_ALIAS_i_f(finite)
+_MATH_ALIAS_i_f(__finite)
+
 #else
 #include "../../common/sf_finite.c"
 #endif
