@@ -33,9 +33,10 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <math.h>
+#include "fdlibm.h"
 
 #if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 32 && __riscv_xlen >= 64
+
 long long int
 llroundf (float x)
 {
@@ -49,6 +50,9 @@ llroundf (float x)
        "\t%0, %1, rmm" : "=r"(result) : "f"(x));
   return result;
 }
+
+_MATH_ALIAS_k_f(llround)
+
 #else
 #include "../../common/sf_llround.c"
 #endif
