@@ -64,7 +64,7 @@ atan264(__float64 y, __float64 x)
     if (((ix | ((lx | -lx) >> 31)) > 0x7ff00000) ||
         ((iy | ((ly | -ly) >> 31)) > 0x7ff00000)) /* x or y is NaN */
         return x + y;
-    if (((hx - 0x3ff00000) | lx) == 0)
+    if ((((__uint32_t) hx - 0x3ff00000) | lx) == 0)
         return atan64(y); /* x=1.0 */
     m = ((hy >> 31) & 1) | ((hx >> 30) & 2); /* 2*sign(x)+sign(y) */
 
