@@ -43,7 +43,7 @@ lgamma64(__float64 x)
     return lgamma64_r(x, &__signgam);
 }
 
-#  ifdef _HAVE_ALIAS_ATTRIBUTE
+#  ifdef __strong_reference
 #ifdef __GNUCLIKE_PRAGMA_DIAGNOSTIC
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wunknown-warning-option"
