@@ -15,8 +15,6 @@
 
 #include "fdlibm.h"
 
-static const float huge = 1.0e30;
-
 float
 ceilf(float x)
 {
@@ -26,23 +24,19 @@ ceilf(float x)
     ix = (i0 & 0x7fffffff);
     j0 = (ix >> 23) - 0x7f;
     if (j0 < 23) {
-        if (j0 < 0) { /* raise inexact if x != 0 */
-            if (huge + x > (float)0.0) { /* return 0*sign(x) if |x|<1 */
-                if (i0 < 0) {
-                    i0 = 0x80000000;
-                } else if (!FLT_UWORD_IS_ZERO(ix)) {
-                    i0 = 0x3f800000;
-                }
+        if (j0 < 0) {
+            if (i0 < 0) {
+                i0 = 0x80000000;
+            } else if (!FLT_UWORD_IS_ZERO(ix)) {
+                i0 = 0x3f800000;
             }
         } else {
             i = (0x007fffff) >> j0;
             if ((i0 & i) == 0)
                 return x; /* x is integral */
-            if (huge + x > (float)0.0) { /* raise inexact flag */
-                if (i0 > 0)
-                    i0 += (0x00800000) >> j0;
-                i0 &= (~i);
-            }
+            if (i0 > 0)
+                i0 += (0x00800000) >> j0;
+            i0 &= (~i);
         }
     } else {
         if (!FLT_UWORD_IS_FINITE(ix))
@@ -54,12 +48,4 @@ ceilf(float x)
     return x;
 }
 
-#ifdef _DOUBLE_IS_32BITS
-
-double
-ceil(double x)
-{
-    return (double)ceilf((float)x);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
+_MATH_ALIAS_f_f(ceil)
