@@ -34,7 +34,7 @@ log10f(float x)
     if (hx < 0)
         return __math_invalidf(x); /* log(-#) = NaN */
     if (!FLT_UWORD_IS_FINITE(hx))
-        return x;
+        return x + x;
     if (FLT_UWORD_IS_SUBNORMAL(hx)) {
         k -= 25;
         x *= two25; /* subnormal number, scale up x */
@@ -48,3 +48,5 @@ log10f(float x)
     z = y * log10_2lo + ivln10 * logf(x);
     return z + y * log10_2hi;
 }
+
+_MATH_ALIAS_f_f(log10)
