@@ -6,7 +6,7 @@
 
 #include "fdlibm.h"
 
-#if defined(_NEED_FLOAT_HUGE) && !defined(_HAVE_LONG_DOUBLE_MATH)
+#if defined(_NEED_FLOAT_HUGE) && !defined(__HAVE_LONG_DOUBLE_MATH)
 
 long double
 hypotl(long double x, long double y)
@@ -17,7 +17,7 @@ hypotl(long double x, long double y)
 
     /* Keep it simple for now...  */
     long double z = sqrtl((x * x) + (y * y));
-#ifdef _WANT_MATH_ERRNO
+#ifdef __MATH_ERRNO
     if (!finite(z) && finite(x) && finite(y))
         errno = ERANGE;
 #endif
