@@ -253,16 +253,16 @@ __math_lgammaf_r(float x, int *signgamp, int *divzero)
         switch (i) {
         case 7:
             z *= (y + (float)6.0);
-	  __PICOLIBC_FALLTHROUGH;
+	  __fallthrough;
         case 6:
             z *= (y + (float)5.0);
-	  __PICOLIBC_FALLTHROUGH;
+	  __fallthrough;
         case 5:
             z *= (y + (float)4.0);
-	  __PICOLIBC_FALLTHROUGH;
+	  __fallthrough;
         case 4:
             z *= (y + (float)3.0);
-	  __PICOLIBC_FALLTHROUGH;
+	  __fallthrough;
         case 3:
             z *= (y + (float)2.0);
             r += logf(z);
