@@ -299,5 +299,6 @@
 {35, 0,123,__LINE__, 0x3fe22970, 0x0128f5e4, 0x403a1999, 0x99999996},	/* 0.567558=f(26.1)*/
 {36, 0,123,__LINE__, 0xbfec7793, 0xbe7da18f, 0x403bcccc, 0xccccccc9},	/* -0.889597=f(27.8)*/
 {34, 0,123,__LINE__, 0xbfd5a705, 0x9eaeab38, 0x403d7fff, 0xfffffffc},	/* -0.338319=f(29.5)*/
-0,};
-void test_cosf(m)   {run_vector_1(m,cosf_vec,(char *)(cosf),"cosf","ff");   }	
+{0}
+};
+void test_cosf(int m)   {run_vector_1(m,cosf_vec,(char *)(cosf),"cosf","ff");   }	
