@@ -306,5 +306,6 @@
 {64, 0,123,__LINE__, 0x7ff00000, 0x00000000, 0xfff00000, 0x00000000},   /* +inf=f(-inf)*/
 {64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},   /* +0=f(+0)*/
 {64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x80000000, 0x00000000},   /* +0=f(-0)*/
-0,};
-void test_fabsf(m)   {run_vector_1(m,fabsf_vec,(char *)(fabsf),"fabsf","ff");   }	
+{0}
+};
+void test_fabsf(int m)   {run_vector_1(m,fabsf_vec,(char *)(fabsf),"fabsf","ff");   }	
