@@ -300,6 +300,7 @@
 {64, 0,123,__LINE__, 0x403a0000, 0x00000000, 0x403a1999, 0x99999996},	/* 26=f(26.1)*/
 {64, 0,123,__LINE__, 0x403b0000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 27=f(27.8)*/
 {64, 0,123,__LINE__, 0x403d0000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 29=f(29.5)*/
+{64, 0,123,__LINE__, 0xc1500000, 0x00000000, 0xc14fffff, 0xc0000000},	/* -0x1p+22=f(-0x1.fffffcp+21)*/
 {64, 0,123,__LINE__, 0x7ff80000, 0x00000000, 0x7ff80000, 0x00000000},   /* qnan=f(qnan)*/
 {64, 0,123,__LINE__, 0x7ff80000, 0x00000000, 0x7ff40000, 0x00000000},   /* qnan=f(snan)*/
 {64, 0,123,__LINE__, 0x7ff00000, 0x00000000, 0x7ff00000, 0x00000000},   /* +inf=f(+inf)*/
@@ -308,4 +309,4 @@
 {64, 0,123,__LINE__, 0x80000000, 0x00000000, 0x80000000, 0x00000000},   /* -0=f(-0)*/
 {0}
 };
-void test_floor(m)   {run_vector_1(m,floor_vec,(char *)(floor),"floor","dd");   }	
+void test_floor(int m)   {run_vector_1(m,floor_vec,(char *)(floor),"floor","dd");   }	
