@@ -296,5 +296,5 @@
 {56, 0,123,__LINE__, 0x3f9f302d, 0x6b54eaf2, 0x403a1999, 0x99999996},	/* 0.0304572=f(26.1)*/
 {64, 0,123,__LINE__, 0x3fc25cf8, 0x6ae10498, 0x403bcccc, 0xccccccc9},	/* 0.143462=f(27.8)*/
 {58, 0,123,__LINE__, 0xbfb07640, 0x70ecf6df, 0x403d7fff, 0xfffffffc},	/* -0.0643044=f(29.5)*/
-0,};
-void test_j1(m)   {run_vector_1(m,j1_vec,(char *)(j1),"j1","dd");   }	
+{0},};
+void test_j1(int m)   {run_vector_1(m,j1_vec,(char *)(j1),"j1","dd");   }	
