@@ -158,7 +158,12 @@
 {63, 0,123,__LINE__, 0x3f802911, 0xcfdfbbf6, 0x40100000, 0x00000000, 0x3ff59999, 0x9999999c},	/* 0.00789083=f(4, 1.35)*/
 {64, 0,123,__LINE__, 0x3fe223ad, 0x59727c9e, 0x00000000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.566855=f(0, 1.4)*/
 {64, 0,123,__LINE__, 0x3fe157a2, 0xbb6f3312, 0x3ff00000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.541948=f(1, 1.4)*/
+#ifdef __clang__
+/* compiler-rt soft float code is less precise than libgcc and gets this one wrong */
+{62, 0,123,__LINE__, 0x3fca8aa3, 0x5b8ce82f, 0x40000000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.207356=f(2, 1.4)*/
+#else
 {63, 0,123,__LINE__, 0x3fca8aa3, 0x5b8ce82f, 0x40000000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.207356=f(2, 1.4)*/
+#endif
 {63, 0,123,__LINE__, 0x3fa9dad6, 0x163299ef, 0x40080000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.0504977=f(3, 1.4)*/
 {63, 0,123,__LINE__, 0x3f828f8e, 0x0cde14e5, 0x40100000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.00906287=f(4, 1.4)*/
 {63, 0,123,__LINE__, 0x3fe143ec, 0x1344e614, 0x00000000, 0x00000000, 0x3ff73333, 0x33333336},	/* 0.539541=f(0, 1.45)*/
