@@ -412,5 +412,5 @@
 {64, 0,123,__LINE__, 0x40113e88, 0x5fdc3280, 0x4033d999, 0x999999c3},	/* 4.31107=f(19.85)*/
 {64, 0,123,__LINE__, 0x4011423f, 0xce576f3a, 0x4033e666, 0x66666690},	/* 4.3147=f(19.9)*/
 {64, 0,123,__LINE__, 0x401145f4, 0xd99d3304, 0x4033f333, 0x3333335d},	/* 4.31832=f(19.95)*/
-0,};
-void test_log2(m)   {run_vector_1(m,log2_vec,(char *)(log2),"log2","dd");   }	
+{0},};
+void test_log2(int m)   {run_vector_1(m,log2_vec,(char *)(log2),"log2","dd");   }	
