@@ -300,5 +300,5 @@
 {36, 0,123,__LINE__, 0x400a1871, 0x80000000, 0x403a1999, 0x99999996},	/* 3.26194=f(26.1)*/
 {37, 0,123,__LINE__, 0x400a99ac, 0x80000000, 0x403bcccc, 0xccccccc9},	/* 3.32504=f(27.8)*/
 {36, 0,123,__LINE__, 0x400b133b, 0x40000000, 0x403d7fff, 0xfffffffc},	/* 3.38439=f(29.5)*/
-0,};
-void test_logf(m)   {run_vector_1(m,logf_vec,(char *)(logf),"logf","ff");   }	
+{0},};
+void test_logf(int m)   {run_vector_1(m,logf_vec,(char *)(logf),"logf","ff");   }	
