@@ -300,5 +300,5 @@
 {31, 0,123,__LINE__, 0x42392eae, 0xa0000000, 0x403a1999, 0x99999996},	/* 1.08157e+11=f(26.1)*/
 {31, 0,123,__LINE__, 0x42613b18, 0x40000000, 0x403bcccc, 0xccccccc9},	/* 5.92047e+11=f(27.8)*/
 {31, 0,123,__LINE__, 0x42879487, 0xa0000000, 0x403d7fff, 0xfffffffc},	/* 3.24084e+12=f(29.5)*/
-0,};
-void test_sinhf(m)   {run_vector_1(m,sinhf_vec,(char *)(sinhf),"sinhf","ff");   }	
+{0},};
+void test_sinhf(int m)   {run_vector_1(m,sinhf_vec,(char *)(sinhf),"sinhf","ff");   }	
