@@ -300,5 +300,5 @@
 {64, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x403a1999, 0x99999996},	/* 1=f(26.1)*/
 {64, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 1=f(27.8)*/
 {64, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 1=f(29.5)*/
-0,};
-void test_tanh(m)   {run_vector_1(m,tanh_vec,(char *)(tanh),"tanh","dd");   }	
+{0},};
+void test_tanh(int m)   {run_vector_1(m,tanh_vec,(char *)(tanh),"tanh","dd");   }	
