@@ -46,7 +46,7 @@ main (int ac,
   int is = 1;
   int math= 1;
   int cvt = 1;
-#ifdef _HAVE_IEEEFP_FUNCS
+#ifdef __IEEEFP_FUNCS
   int ieee= 1;
 #endif
   int vector=0;
@@ -68,7 +68,7 @@ main (int ac,
     (void) math;
     if (strcmp(av[i],"-nocvt") == 0)
      cvt = 0;
-#ifdef _HAVE_IEEEFP_FUNCS
+#ifdef __IEEEFP_FUNCS
     if (strcmp(av[i],"-noiee") == 0)
      ieee= 0;
   (void) ieee;
@@ -78,6 +78,10 @@ main (int ac,
      calc = 1;
     }
   }
+  if (sizeof (double) < 8) {
+      printf("Skipping math tests on target without 64-bit double\n");
+      exit(77);
+  }
   if (cvt)
    test_cvt();
 
@@ -92,25 +96,31 @@ main (int ac,
 #if TEST_PART == 0 || TEST_PART == -1
   if (is)
    test_is();
-#ifdef _HAVE_IEEEFP_FUNCS
+#ifdef __IEEEFP_FUNCS
   if (ieee)
    test_ieee();
 #endif
 #endif
   printf("Tested %d functions, %d errors detected\n", count, inacc);
+#ifdef __RX__
+  if (inacc != 0) {
+    printf("Expected failure on RX target, ignoring\n");
+    exit(77);
+  }
+#endif
   exit(inacc != 0);
 }
 
-static const char *iname = "foo";
+static const char *iname;
 void newfunc (const char *string)
 {
-  if (strcmp(iname, string)) 
+  if (!iname || strcmp(iname, string)) 
   {
 #ifdef MALLOC_DEBUG
     char *memcheck = getenv("CHECK_NAME");
     if (memcheck && !strcmp(string, memcheck))
       _malloc_test_fail = atoi(getenv("CHECK_COUNT"));
-    if (memcheck && !strcmp(iname, memcheck)) {
+    if (memcheck && iname && !strcmp(iname, memcheck)) {
       if (_malloc_test_fail) {
 	printf("malloc test fail remain %d\n", _malloc_test_fail);
 	_malloc_test_fail = 0;
@@ -183,7 +193,7 @@ int
 mag_of_error (double is,
        double shouldbe)
 {
-  __ieee_double_shape_type a,b;
+  __ieee_double_shape_type a = {},b = {};
   int i;
   int a_big;
   uint32_t mask;
@@ -268,7 +278,7 @@ fmag_of_error (float is,
     b.p1 = t;
   }
 
-  sw = (a.p1) - (b.p1);
+  sw = (uint32_t) (a.p1) - (uint32_t) (b.p1);
 
   mask = 0x80000000UL;
   for (i = 0; i < 32; i++)
@@ -365,7 +375,7 @@ test_mok (double value,
        double shouldbe,
        int okmag)
 {
-  __ieee_double_shape_type a,b;
+  __ieee_double_shape_type a = {},b = {};
   int mag = mag_of_error(value, shouldbe);
   if (mag == 0) 
   {
@@ -374,6 +384,12 @@ test_mok (double value,
      return;
     
   }
+#ifdef __RX__
+  /* RX doesn't support nan or inf at all */
+  if (isnan(shouldbe) || isinf(shouldbe))
+      mag = 64;
+#endif
+
   a.value = shouldbe;
   b.value = value;
   
@@ -405,6 +421,17 @@ test_mfok (float value,
      return;
     
   }
+#ifdef __RX__
+  /* RX doesn't support nan or inf at all */
+  if (isnan(shouldbe) || isinf(shouldbe))
+      mag = 32;
+#endif
+#ifdef __sh__
+  /* SuperH has a different canonical representation for nans */
+  if (!!isnan(shouldbe) == !!isnan(value) &&
+      !!__issignalingf(shouldbe) == !!__issignalingf(value))
+      mag = 32;
+#endif
   a.value = shouldbe;
   b.value = value;
   
