@@ -300,6 +300,10 @@
 {64, 0,123,__LINE__, 0x403a0000, 0x00000000, 0x403a1999, 0x99999996},	/* 26=f(26.1)*/
 {64, 0,123,__LINE__, 0x403b0000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 27=f(27.8)*/
 {64, 0,123,__LINE__, 0x403d0000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 29=f(29.5)*/
+{64, 0,123,__LINE__, 0x441abcde, 0x23456789, 0x441abcde, 0x23456789},   /* 1.23306e+20 = f(1.23306+20) */
+{64, 0,123,__LINE__, 0xc41abcde, 0x23456789, 0xc41abcde, 0x23456789},   /* -1.23306e+20 = f(-1.23306+20) */
+{64, 0,123,__LINE__, 0x7fefffff, 0xffffffff, 0x7fefffff, 0xffffffff},   /* 1.797693e+308 = f(1.797693e+308) */
+{64, 0,123,__LINE__, 0xffefffff, 0xffffffff, 0xffefffff, 0xffffffff},   /* -1.797693e+308 = f(-1.797693e+308) */
 {64, 0,123,__LINE__, 0x7ff80000, 0x00000000, 0x7ff80000, 0x00000000},   /* qnan=f(qnan)*/
 {64, 0,123,__LINE__, 0x7ff80000, 0x00000000, 0x7ff40000, 0x00000000},   /* qnan=f(snan)*/
 {64, 0,123,__LINE__, 0x7ff00000, 0x00000000, 0x7ff00000, 0x00000000},   /* +inf=f(+inf)*/
