@@ -300,6 +300,10 @@
 {64, 0,123,__LINE__, 0x403a0000, 0x00000000, 0x403a1999, 0x99999996},	/* 26=f(26.1)*/
 {64, 0,123,__LINE__, 0x403b0000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 27=f(27.8)*/
 {64, 0,123,__LINE__, 0x403d0000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 29=f(29.5)*/
+{64, 0,123,__LINE__, 0x420abcde, 0xe0000000, 0x420abcde, 0xe0000000},   /* 1.435474e+10 = f(1.435474+10) */
+{64, 0,123,__LINE__, 0xc20abcde, 0xe0000000, 0xc20abcde, 0xe0000000},   /* -1.435474e+10 = f(-1.435474+10) */
+{64, 0,123,__LINE__, 0x47efffff, 0xe0000000, 0x47efffff, 0xe0000000},   /* 3.402823e38 = f(3.402823e38) */
+{64, 0,123,__LINE__, 0xc7efffff, 0xe0000000, 0xc7efffff, 0xe0000000},   /* -3.402823e38 = f(-3.402823e38) */
 {64, 0,123,__LINE__, 0x7ff80000, 0x00000000, 0x7ff80000, 0x00000000},   /* qnan=f(qnan)*/
 {64, 0,123,__LINE__, 0x7ff80000, 0x00000000, 0x7ff40000, 0x00000000},   /* qnan=f(snan)*/
 {64, 0,123,__LINE__, 0x7ff00000, 0x00000000, 0x7ff00000, 0x00000000},   /* +inf=f(+inf)*/
