@@ -300,5 +300,5 @@
 {62, 0,123,__LINE__, 0xbfc39cd0, 0xcf7f5219, 0x403a1999, 0x99999996},	/* -0.153223=f(26.1)*/
 {58, 0,123,__LINE__, 0x3fa8b66b, 0x1871711a, 0x403bcccc, 0xccccccc9},	/* 0.0482667=f(27.8)*/
 {61, 0,123,__LINE__, 0x3fc0e92b, 0x1cafe2d5, 0x403d7fff, 0xfffffffc},	/* 0.132116=f(29.5)*/
-0,};
-void test_y1(m)   {run_vector_1(m,y1_vec,(char *)(y1),"y1","dd");   }	
+{0},};
+void test_y1(int m)   {run_vector_1(m,y1_vec,(char *)(y1),"y1","dd");   }	
