@@ -6,12 +6,14 @@ is freely granted, provided that this notice is preserved.
  */
 #include <stdio.h>
 #include <stdlib.h>
+#include <errno.h>
 
 #define CHECK(a) { \
   if (!(a)) \
     { \
+      int err = errno; \
       printf ("Failed " #a " in <%s> at line %d\n", __FILE__, __LINE__); \
       fflush(stdout); \
-      exit(1); \
+      exit(err == ENOMEM ? 77 : 1); \
     } \
 }
