@@ -12,7 +12,7 @@
 
 int main(void)
 {
-#if defined(INTEGER_ONLY) || defined(NO_FLOATING_POINT)
+#if defined(INTEGER_ONLY) || defined(__IO_NO_FLOATING_POINT)
 
 #else
   char cbuf[512];
