@@ -8,7 +8,7 @@ is freely granted, provided that this notice is preserved.
 #include <stdint.h>
 #include <stdlib.h>
 
-int main () {
+int main (void) {
   size_t s;
 
   s = SIZE_MAX;
@@ -20,5 +20,5 @@ int main () {
   if (++s != 0)
     abort ();
 
-  return 0;
+  exit(0);
 }
