@@ -37,7 +37,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-_Noreturn void
+__noreturn void
 _exit(int code)
 {
         char buf[15];
