@@ -42,7 +42,7 @@
 #include <errno.h>
 #include <stdbool.h>
 
-static int fd_stdin, fd_stdout, fd_stderr;
+static int fd_stdout, fd_stderr;
 static bool _check_done;
 
 int
@@ -50,13 +50,12 @@ _map_stdio(int fd)
 {
 	if (!_check_done) {
 		_check_done = true;
-		fd_stdin = sys_semihost_open(":tt", 0);
 		fd_stdout = sys_semihost_open(":tt", 4);
 		fd_stderr = sys_semihost_open(":tt", 8);
 	}
 	switch (fd) {
-	case 0:
-		return fd_stdin;
+        case 0:
+                return -1;
 	case 1:
 		return fd_stdout;
 	case 2:
