@@ -87,7 +87,7 @@ check_long_double(const char *name, int i, long double prec, long double expect,
     if (!within_error(expect, result, prec)) {
         long double diff = fabsl(expect - result);
 #ifdef __PICOLIBC__
-#ifdef _WANT_IO_LONG_DOUBLE
+#ifdef __IO_LONG_DOUBLE
         printf("%s test %d got %La expect %La diff %La\n", name, i, result, expect, diff);
 #else
         printf("%s test %d got %a expect %a diff %a\n", name, i, (double) result, (double) expect, (double) diff);
@@ -112,25 +112,35 @@ check_long_long(const char *name, int i, long long expect, long long result)
     return 0;
 }
 
-typedef const struct {
-    const char *name;
+/*
+ * Force the large table to be loaded into RAM as the PID area
+ * of read-only data is only 64kB
+ */
+#ifdef _RX_PID
+#define CONST volatile
+#else
+#define CONST const
+#endif
+
+typedef CONST struct {
+    CONST char *name;
     int (*test)(void);
 } long_double_test_t;
 
-typedef const struct {
+typedef CONST struct {
     int line;
     long double x;
     long double y;
 } long_double_test_f_f_t;
 
-typedef const struct {
+typedef CONST struct {
     int line;
     long double x0;
     long double x1;
     long double y;
 } long_double_test_f_ff_t;
 
-typedef const struct {
+typedef CONST struct {
     int line;
     long double x0;
     long double x1;
@@ -138,14 +148,14 @@ typedef const struct {
     long double y;
 } long_double_test_f_fff_t;
 
-typedef const struct {
+typedef CONST struct {
     int line;
     long double x0;
     int x1;
     long double y;
 } long_double_test_f_fi_t;
 
-typedef const struct {
+typedef CONST struct {
     int line;
     long double x;
     long long y;
@@ -173,6 +183,9 @@ typedef const struct {
 #elif LDBL_MANT_DIG == 53
 #define DEFAULT_PREC 0x1p-48L
 #define SQRTL_PREC 0x1.0p-52L
+#elif LDBL_MANT_DIG == 24
+#define DEFAULT_PREC 0x1p-21L
+#define SQRTL_PREC 0x1.0p-23L
 #else
 #error unsupported long double
 #endif
@@ -195,20 +208,20 @@ typedef const struct {
 
 #include "long_double_vec.h"
 
-#if !defined(__PICOLIBC__) || (defined(_WANT_IO_LONG_DOUBLE) && (defined(TINY_STDIO) || defined(FLOATING_POINT)))
+#if !defined(__PICOLIBC__) || (defined(__IO_LONG_DOUBLE) && (defined(__TINY_STDIO) || defined(__IO_FLOATING_POINT)))
 #define TEST_IO_LONG_DOUBLE
 #endif
 
-#if defined(__PICOLIBC__) && defined(__m68k__) && !defined(TINY_STDIO)
+#if defined(__PICOLIBC__) && defined(__m68k__) && !defined(__TINY_STDIO)
 #undef TEST_IO_LONG_DOUBLE
 #endif
 
-#if defined(__PICOLIBC__) && !defined(TINY_STDIO) && __LDBL_MANT_DIG__ != 64
+#if defined(__PICOLIBC__) && !defined(__TINY_STDIO) && __LDBL_MANT_DIG__ != 64
 #undef TEST_IO_LONG_DOUBLE
 #endif
 
 #ifdef TEST_IO_LONG_DOUBLE
-static long double vals[] = {
+static const long double vals[] = {
     1.0L,
     0x1.8p0L,
     3.141592653589793238462643383279502884197169L,
@@ -339,7 +352,7 @@ naive_strtold(const char *buf)
         return ldexpl(v, exp * exp_sign);
 }
 
-static const char *formats[] = { "%La", "%.30Le", };
+static const char * const formats[] = { "%La", "%.30Le", };
 
 #define NFMTS (sizeof (formats)/sizeof(formats[0]))
 
@@ -390,14 +403,16 @@ static const int test_exp[] = {
  * For 64-bit values, we may have exact conversions. Otherwise, allow
  * some error
  */
-#ifdef _IO_FLOAT_EXACT
+#ifdef __IO_FLOAT_EXACT
 # if __SIZEOF_LONG_DOUBLE__ == 8
 #  define MAX_DECIMAL_ERROR       0
 # else
 #  define MAX_DECIMAL_ERROR     1e-10L
 # endif
 #else
-# if __SIZEOF_LONG_DOUBLE__ == 8
+# if __SIZEOF_LONG_DOUBLE__ == 4
+#  define MAX_DECIMAL_ERROR       1e-2L
+# elif __SIZEOF_LONG_DOUBLE__ == 8
 #  define MAX_DECIMAL_ERROR       1e-5L
 # else
 #  define MAX_DECIMAL_ERROR       1e-10L
@@ -435,28 +450,51 @@ test_io(void)
                 if (isinf(v)) {
                     if (strcmp(buf, "inf") != 0) {
                         printf("test_io i %d val %La exp %d: is %s should be inf\n", i, vals[i], test_exp[e], buf);
+#ifdef __RX__
+                        printf("ignoring error on RX\n");
+#else
                         result++;
+#endif
                     }
                 } else if (isnan(v)) {
                     if (strcmp(buf, "nan") != 0) {
                         printf("test_io is %s should be nan\n", buf);
+#ifdef __RX__
+                        printf("ignoring error on RX\n");
+#else
                         result++;
+#endif
                     }
                 } else {
                     r = naive_strtold(buf);
                     if (!close(r, v, max_error_naive)) {
                         printf("test_io naive i %d val %La exp %d: \"%s\", is %La should be %La\n", i, vals[i], test_exp[e], buf, r, v);
+#ifdef __RX__
+                        if (!isnormal(v) || !isnormal(r))
+                            printf("ignoring error on RX\n");
+                        else
+#endif
                         result++;
                     }
                 }
                 sscanf(buf, "%Lf", &r);
                 if (!close(r, v, max_error) && !(isnan(v) && isnan(r))) {
                     printf("test_io scanf i %d val %La exp %d: \"%s\", is %La should be %La\n", i, vals[i], test_exp[e], buf, r, v);
+#ifdef __RX__
+                    if (!isnormal(v) || !isnormal(r))
+                        printf("ignoring error on RX\n");
+                    else
+#endif
                     result++;
                 }
                 r = strtold(buf, &end);
                 if ((!close(r, v, max_error) && !(isnan(v) && isnan(r)))|| end != buf + strlen(buf)) {
                     printf("test_io strtold i %d val %La exp %d: \"%s\", is %La should be %La\n", i, vals[i], test_exp[e], buf, r, v);
+#ifdef __RX__
+                    if (!isnormal(v) || !isnormal(r))
+                        printf("ignoring error on RX\n");
+                    else
+#endif
                     result++;
                 }
             }
@@ -503,7 +541,7 @@ test_conv(void)
     for (i = 0; i <= 0xffff; i += STEP_I) {
         for (j = 0; j < 0xf; j += STEP_J) {
             for (k = 0; k < 0x2; k++) {
-                dl.l.upper = i << 16;
+                dl.l.upper = (unsigned long) i << 16;
                 dl.l.lower = (j << 28) | k;
                 ld = (long double) dl.d;
                 if (fabsl(ld) > 1) {
@@ -521,7 +559,7 @@ test_conv(void)
                     ret++;
                 }
 
-                fl.l = (i << 16) | k;
+                fl.l = ((unsigned long) i << 16) | k;
                 ld = (long double) fl.f;
                 f = (float) ld;
                 if (isnan(f) && isnan(fl.f))
