@@ -80,7 +80,7 @@ main(void)
 		return 1;
 	}
 
-#if defined(TINY_STDIO) || !defined(_HAVE_SEMIHOST)
+#if defined(__TINY_STDIO) || !defined(__SEMIHOST)
         if (fseeko(f, -3, SEEK_CUR) < 0) {
                 printf("failed to seek back 3 bytes\n");
                 return 1;
