@@ -46,7 +46,7 @@
 static volatile bool expect_smash;
 
 static void __attribute__((noinline))
-#ifdef _HAVE_CC_INHIBIT_LOOP_TO_LIBCALL
+#ifdef __HAVE_CC_INHIBIT_LOOP_TO_LIBCALL
 __attribute((__optimize__("-fno-tree-loop-distribute-patterns")))
 #endif
     my_strcpy(char *d, char *s)
@@ -67,12 +67,12 @@ void
 __stack_chk_fail (void)
 {
 	if (expect_smash) {
-#ifdef TINY_STDIO
+#ifdef __TINY_STDIO
 		puts("caught expected stack smash");
 #endif
 		_exit(0);
 	} else {
-#ifdef TINY_STDIO
+#ifdef __TINY_STDIO
 		puts("caught unexpected stack smash");
 #endif
 		_exit(1);
