@@ -64,19 +64,19 @@
         }                                                               \
     } while(0)
 
-#ifdef _MB_EXTENDED_CHARSETS_ISO
+#ifdef __MB_EXTENDED_CHARSETS_ISO
 #define HAVE_ISO_CHARSETS
 #endif
 
-#ifdef _MB_EXTENDED_CHARSETS_WINDOWS
+#ifdef __MB_EXTENDED_CHARSETS_WINDOWS
 #define HAVE_WINDOWS_CHARSETS
 #endif
 
-#ifdef _MB_EXTENDED_CHARSETS_JIS
+#ifdef __MB_EXTENDED_CHARSETS_JIS
 #define HAVE_JIS_CHARSETS
 #endif
 
-static const char *locales[] = {
+static const char *const locales[] = {
     "C",
 #define C_LOCALE        0
 #ifdef HAVE_ISO_CHARSETS
