@@ -49,7 +49,7 @@ main(void)
 #ifdef __thumb__
     __asm__(".inst.n 0xde00");
 #else
-    __asm__(".word 0xe7f000f0");
+    __asm__(".inst 0xe7f000f0");
 #endif
 
 #elif defined(__riscv)
@@ -60,6 +60,14 @@ main(void)
 
     __asm__(".word 0x00000000");
 
+#elif defined(__RX__)
+
+    __asm__(".word 0xffffffff");
+
+#elif defined(__x86_64__) || defined(__i386__)
+
+    __asm__("ud2");
+
 #else
 
 #define NO_INVALID
