@@ -53,10 +53,15 @@
 static void
 abrt_handler(int sig)
 {
-    if (sig == (int) SIGABRT)
+    if (sig == (int) SIGABRT) {
+#ifdef SANITIZE_TRAP_ON_ERROR
+        _Exit(1);
+#else
         _Exit(0);
+#endif
+    }
     else {
-#ifdef TINY_STDIO
+#ifdef __TINY_STDIO
         printf("unexpected signal %d\n", sig);
         fflush(stdout);
 #endif
